diff --git a/packages/SystemUI/res/anim/tv_pip_onboarding_background_enter_animation.xml b/packages/SystemUI/res/anim/tv_pip_onboarding_background_enter_animation.xml
deleted file mode 100644
index 9ab41d0be5253..0000000000000
--- a/packages/SystemUI/res/anim/tv_pip_onboarding_background_enter_animation.xml
+++ /dev/null
@@ -1,25 +0,0 @@
-
-
-
-
-
-
-
diff --git a/packages/SystemUI/res/anim/tv_pip_onboarding_button_enter_animation.xml b/packages/SystemUI/res/anim/tv_pip_onboarding_button_enter_animation.xml
deleted file mode 100644
index 01c263b052177..0000000000000
--- a/packages/SystemUI/res/anim/tv_pip_onboarding_button_enter_animation.xml
+++ /dev/null
@@ -1,30 +0,0 @@
-
-
-
-
-
-
-
-
diff --git a/packages/SystemUI/res/anim/tv_pip_onboarding_description_enter_animation.xml b/packages/SystemUI/res/anim/tv_pip_onboarding_description_enter_animation.xml
deleted file mode 100644
index a12b3b6806138..0000000000000
--- a/packages/SystemUI/res/anim/tv_pip_onboarding_description_enter_animation.xml
+++ /dev/null
@@ -1,30 +0,0 @@
-
-
-
-
-
-
-
-
diff --git a/packages/SystemUI/res/anim/tv_pip_onboarding_image_enter_animation.xml b/packages/SystemUI/res/anim/tv_pip_onboarding_image_enter_animation.xml
deleted file mode 100644
index ae9677ed8a0ac..0000000000000
--- a/packages/SystemUI/res/anim/tv_pip_onboarding_image_enter_animation.xml
+++ /dev/null
@@ -1,30 +0,0 @@
-
-
-
-
-
-
-
-
diff --git a/packages/SystemUI/res/anim/tv_pip_onboarding_title_enter_animation.xml b/packages/SystemUI/res/anim/tv_pip_onboarding_title_enter_animation.xml
deleted file mode 100644
index 4bde070dafbec..0000000000000
--- a/packages/SystemUI/res/anim/tv_pip_onboarding_title_enter_animation.xml
+++ /dev/null
@@ -1,30 +0,0 @@
-
-
-
-
-
-
-
-
diff --git a/packages/SystemUI/res/anim/tv_pip_overlay_fade_in_animation.xml b/packages/SystemUI/res/anim/tv_pip_overlay_fade_in_animation.xml
deleted file mode 100644
index 33bceaa77ce98..0000000000000
--- a/packages/SystemUI/res/anim/tv_pip_overlay_fade_in_animation.xml
+++ /dev/null
@@ -1,21 +0,0 @@
-
-
-
-
diff --git a/packages/SystemUI/res/anim/tv_pip_overlay_fade_out_animation.xml b/packages/SystemUI/res/anim/tv_pip_overlay_fade_out_animation.xml
deleted file mode 100644
index a12ddffc0bfc7..0000000000000
--- a/packages/SystemUI/res/anim/tv_pip_overlay_fade_out_animation.xml
+++ /dev/null
@@ -1,21 +0,0 @@
-
-
-
-
diff --git a/packages/SystemUI/res/drawable-xhdpi/remote_0.png b/packages/SystemUI/res/drawable-xhdpi/remote_0.png
deleted file mode 100644
index 5bda52e3b0896..0000000000000
Binary files a/packages/SystemUI/res/drawable-xhdpi/remote_0.png and /dev/null differ
diff --git a/packages/SystemUI/res/drawable-xhdpi/remote_1.png b/packages/SystemUI/res/drawable-xhdpi/remote_1.png
deleted file mode 100644
index 252ff5ed49713..0000000000000
Binary files a/packages/SystemUI/res/drawable-xhdpi/remote_1.png and /dev/null differ
diff --git a/packages/SystemUI/res/drawable-xhdpi/remote_10.png b/packages/SystemUI/res/drawable-xhdpi/remote_10.png
deleted file mode 100644
index 5e52b378abfed..0000000000000
Binary files a/packages/SystemUI/res/drawable-xhdpi/remote_10.png and /dev/null differ
diff --git a/packages/SystemUI/res/drawable-xhdpi/remote_100.png b/packages/SystemUI/res/drawable-xhdpi/remote_100.png
deleted file mode 100644
index f604808357cae..0000000000000
Binary files a/packages/SystemUI/res/drawable-xhdpi/remote_100.png and /dev/null differ
diff --git a/packages/SystemUI/res/drawable-xhdpi/remote_101.png b/packages/SystemUI/res/drawable-xhdpi/remote_101.png
deleted file mode 100644
index 0272e45267d65..0000000000000
Binary files a/packages/SystemUI/res/drawable-xhdpi/remote_101.png and /dev/null differ
diff --git a/packages/SystemUI/res/drawable-xhdpi/remote_102.png b/packages/SystemUI/res/drawable-xhdpi/remote_102.png
deleted file mode 100644
index aaa35c01bb260..0000000000000
Binary files a/packages/SystemUI/res/drawable-xhdpi/remote_102.png and /dev/null differ
diff --git a/packages/SystemUI/res/drawable-xhdpi/remote_103.png b/packages/SystemUI/res/drawable-xhdpi/remote_103.png
deleted file mode 100644
index 20f95a5827375..0000000000000
Binary files a/packages/SystemUI/res/drawable-xhdpi/remote_103.png and /dev/null differ
diff --git a/packages/SystemUI/res/drawable-xhdpi/remote_104.png b/packages/SystemUI/res/drawable-xhdpi/remote_104.png
deleted file mode 100644
index 052f23e67d3f4..0000000000000
Binary files a/packages/SystemUI/res/drawable-xhdpi/remote_104.png and /dev/null differ
diff --git a/packages/SystemUI/res/drawable-xhdpi/remote_105.png b/packages/SystemUI/res/drawable-xhdpi/remote_105.png
deleted file mode 100644
index c5c82566d62a2..0000000000000
Binary files a/packages/SystemUI/res/drawable-xhdpi/remote_105.png and /dev/null differ
diff --git a/packages/SystemUI/res/drawable-xhdpi/remote_106.png b/packages/SystemUI/res/drawable-xhdpi/remote_106.png
deleted file mode 100644
index 4e804feaf18ac..0000000000000
Binary files a/packages/SystemUI/res/drawable-xhdpi/remote_106.png and /dev/null differ
diff --git a/packages/SystemUI/res/drawable-xhdpi/remote_107.png b/packages/SystemUI/res/drawable-xhdpi/remote_107.png
deleted file mode 100644
index 76669ccd2193e..0000000000000
Binary files a/packages/SystemUI/res/drawable-xhdpi/remote_107.png and /dev/null differ
diff --git a/packages/SystemUI/res/drawable-xhdpi/remote_108.png b/packages/SystemUI/res/drawable-xhdpi/remote_108.png
deleted file mode 100644
index c1b2f3bb5a1ac..0000000000000
Binary files a/packages/SystemUI/res/drawable-xhdpi/remote_108.png and /dev/null differ
diff --git a/packages/SystemUI/res/drawable-xhdpi/remote_109.png b/packages/SystemUI/res/drawable-xhdpi/remote_109.png
deleted file mode 100644
index 79e1d7b221b02..0000000000000
Binary files a/packages/SystemUI/res/drawable-xhdpi/remote_109.png and /dev/null differ
diff --git a/packages/SystemUI/res/drawable-xhdpi/remote_11.png b/packages/SystemUI/res/drawable-xhdpi/remote_11.png
deleted file mode 100644
index cfec6cbd47221..0000000000000
Binary files a/packages/SystemUI/res/drawable-xhdpi/remote_11.png and /dev/null differ
diff --git a/packages/SystemUI/res/drawable-xhdpi/remote_110.png b/packages/SystemUI/res/drawable-xhdpi/remote_110.png
deleted file mode 100644
index d90229739200c..0000000000000
Binary files a/packages/SystemUI/res/drawable-xhdpi/remote_110.png and /dev/null differ
diff --git a/packages/SystemUI/res/drawable-xhdpi/remote_111.png b/packages/SystemUI/res/drawable-xhdpi/remote_111.png
deleted file mode 100644
index e48ed0b4c3c48..0000000000000
Binary files a/packages/SystemUI/res/drawable-xhdpi/remote_111.png and /dev/null differ
diff --git a/packages/SystemUI/res/drawable-xhdpi/remote_112.png b/packages/SystemUI/res/drawable-xhdpi/remote_112.png
deleted file mode 100644
index 90dd1a232cb3e..0000000000000
Binary files a/packages/SystemUI/res/drawable-xhdpi/remote_112.png and /dev/null differ
diff --git a/packages/SystemUI/res/drawable-xhdpi/remote_113.png b/packages/SystemUI/res/drawable-xhdpi/remote_113.png
deleted file mode 100644
index 8fb4ad2aad87a..0000000000000
Binary files a/packages/SystemUI/res/drawable-xhdpi/remote_113.png and /dev/null differ
diff --git a/packages/SystemUI/res/drawable-xhdpi/remote_114.png b/packages/SystemUI/res/drawable-xhdpi/remote_114.png
deleted file mode 100644
index 76873fb355345..0000000000000
Binary files a/packages/SystemUI/res/drawable-xhdpi/remote_114.png and /dev/null differ
diff --git a/packages/SystemUI/res/drawable-xhdpi/remote_115.png b/packages/SystemUI/res/drawable-xhdpi/remote_115.png
deleted file mode 100644
index e923d4c53d198..0000000000000
Binary files a/packages/SystemUI/res/drawable-xhdpi/remote_115.png and /dev/null differ
diff --git a/packages/SystemUI/res/drawable-xhdpi/remote_116.png b/packages/SystemUI/res/drawable-xhdpi/remote_116.png
deleted file mode 100644
index 41d512488e4a5..0000000000000
Binary files a/packages/SystemUI/res/drawable-xhdpi/remote_116.png and /dev/null differ
diff --git a/packages/SystemUI/res/drawable-xhdpi/remote_117.png b/packages/SystemUI/res/drawable-xhdpi/remote_117.png
deleted file mode 100644
index eacde64469531..0000000000000
Binary files a/packages/SystemUI/res/drawable-xhdpi/remote_117.png and /dev/null differ
diff --git a/packages/SystemUI/res/drawable-xhdpi/remote_118.png b/packages/SystemUI/res/drawable-xhdpi/remote_118.png
deleted file mode 100644
index 5dc1fb035f2ab..0000000000000
Binary files a/packages/SystemUI/res/drawable-xhdpi/remote_118.png and /dev/null differ
diff --git a/packages/SystemUI/res/drawable-xhdpi/remote_119.png b/packages/SystemUI/res/drawable-xhdpi/remote_119.png
deleted file mode 100644
index a16f037f1599a..0000000000000
Binary files a/packages/SystemUI/res/drawable-xhdpi/remote_119.png and /dev/null differ
diff --git a/packages/SystemUI/res/drawable-xhdpi/remote_12.png b/packages/SystemUI/res/drawable-xhdpi/remote_12.png
deleted file mode 100644
index 28bb387291e9b..0000000000000
Binary files a/packages/SystemUI/res/drawable-xhdpi/remote_12.png and /dev/null differ
diff --git a/packages/SystemUI/res/drawable-xhdpi/remote_120.png b/packages/SystemUI/res/drawable-xhdpi/remote_120.png
deleted file mode 100644
index fe3ef41769911..0000000000000
Binary files a/packages/SystemUI/res/drawable-xhdpi/remote_120.png and /dev/null differ
diff --git a/packages/SystemUI/res/drawable-xhdpi/remote_121.png b/packages/SystemUI/res/drawable-xhdpi/remote_121.png
deleted file mode 100644
index ef2b892ffe6d5..0000000000000
Binary files a/packages/SystemUI/res/drawable-xhdpi/remote_121.png and /dev/null differ
diff --git a/packages/SystemUI/res/drawable-xhdpi/remote_122.png b/packages/SystemUI/res/drawable-xhdpi/remote_122.png
deleted file mode 100644
index 53429765345c7..0000000000000
Binary files a/packages/SystemUI/res/drawable-xhdpi/remote_122.png and /dev/null differ
diff --git a/packages/SystemUI/res/drawable-xhdpi/remote_123.png b/packages/SystemUI/res/drawable-xhdpi/remote_123.png
deleted file mode 100644
index bb8a53a5aa682..0000000000000
Binary files a/packages/SystemUI/res/drawable-xhdpi/remote_123.png and /dev/null differ
diff --git a/packages/SystemUI/res/drawable-xhdpi/remote_124.png b/packages/SystemUI/res/drawable-xhdpi/remote_124.png
deleted file mode 100644
index b68337e53e9da..0000000000000
Binary files a/packages/SystemUI/res/drawable-xhdpi/remote_124.png and /dev/null differ
diff --git a/packages/SystemUI/res/drawable-xhdpi/remote_125.png b/packages/SystemUI/res/drawable-xhdpi/remote_125.png
deleted file mode 100644
index 81fa3a789542e..0000000000000
Binary files a/packages/SystemUI/res/drawable-xhdpi/remote_125.png and /dev/null differ
diff --git a/packages/SystemUI/res/drawable-xhdpi/remote_126.png b/packages/SystemUI/res/drawable-xhdpi/remote_126.png
deleted file mode 100644
index 2339d74f33e07..0000000000000
Binary files a/packages/SystemUI/res/drawable-xhdpi/remote_126.png and /dev/null differ
diff --git a/packages/SystemUI/res/drawable-xhdpi/remote_127.png b/packages/SystemUI/res/drawable-xhdpi/remote_127.png
deleted file mode 100644
index 90d1e0b453df2..0000000000000
Binary files a/packages/SystemUI/res/drawable-xhdpi/remote_127.png and /dev/null differ
diff --git a/packages/SystemUI/res/drawable-xhdpi/remote_128.png b/packages/SystemUI/res/drawable-xhdpi/remote_128.png
deleted file mode 100644
index 6de4eb8cb77bb..0000000000000
Binary files a/packages/SystemUI/res/drawable-xhdpi/remote_128.png and /dev/null differ
diff --git a/packages/SystemUI/res/drawable-xhdpi/remote_129.png b/packages/SystemUI/res/drawable-xhdpi/remote_129.png
deleted file mode 100644
index 908607425ff88..0000000000000
Binary files a/packages/SystemUI/res/drawable-xhdpi/remote_129.png and /dev/null differ
diff --git a/packages/SystemUI/res/drawable-xhdpi/remote_13.png b/packages/SystemUI/res/drawable-xhdpi/remote_13.png
deleted file mode 100644
index a1e212dc4f110..0000000000000
Binary files a/packages/SystemUI/res/drawable-xhdpi/remote_13.png and /dev/null differ
diff --git a/packages/SystemUI/res/drawable-xhdpi/remote_130.png b/packages/SystemUI/res/drawable-xhdpi/remote_130.png
deleted file mode 100644
index 2bc9698cc095f..0000000000000
Binary files a/packages/SystemUI/res/drawable-xhdpi/remote_130.png and /dev/null differ
diff --git a/packages/SystemUI/res/drawable-xhdpi/remote_131.png b/packages/SystemUI/res/drawable-xhdpi/remote_131.png
deleted file mode 100644
index d18d2c6729923..0000000000000
Binary files a/packages/SystemUI/res/drawable-xhdpi/remote_131.png and /dev/null differ
diff --git a/packages/SystemUI/res/drawable-xhdpi/remote_132.png b/packages/SystemUI/res/drawable-xhdpi/remote_132.png
deleted file mode 100644
index 10a00cdd06bf5..0000000000000
Binary files a/packages/SystemUI/res/drawable-xhdpi/remote_132.png and /dev/null differ
diff --git a/packages/SystemUI/res/drawable-xhdpi/remote_133.png b/packages/SystemUI/res/drawable-xhdpi/remote_133.png
deleted file mode 100644
index 6f495b42513a8..0000000000000
Binary files a/packages/SystemUI/res/drawable-xhdpi/remote_133.png and /dev/null differ
diff --git a/packages/SystemUI/res/drawable-xhdpi/remote_134.png b/packages/SystemUI/res/drawable-xhdpi/remote_134.png
deleted file mode 100644
index 703f2c6342638..0000000000000
Binary files a/packages/SystemUI/res/drawable-xhdpi/remote_134.png and /dev/null differ
diff --git a/packages/SystemUI/res/drawable-xhdpi/remote_135.png b/packages/SystemUI/res/drawable-xhdpi/remote_135.png
deleted file mode 100644
index f4105b0a38abe..0000000000000
Binary files a/packages/SystemUI/res/drawable-xhdpi/remote_135.png and /dev/null differ
diff --git a/packages/SystemUI/res/drawable-xhdpi/remote_136.png b/packages/SystemUI/res/drawable-xhdpi/remote_136.png
deleted file mode 100644
index 0c3a5bcdc8a3c..0000000000000
Binary files a/packages/SystemUI/res/drawable-xhdpi/remote_136.png and /dev/null differ
diff --git a/packages/SystemUI/res/drawable-xhdpi/remote_137.png b/packages/SystemUI/res/drawable-xhdpi/remote_137.png
deleted file mode 100644
index cbebc05275e62..0000000000000
Binary files a/packages/SystemUI/res/drawable-xhdpi/remote_137.png and /dev/null differ
diff --git a/packages/SystemUI/res/drawable-xhdpi/remote_138.png b/packages/SystemUI/res/drawable-xhdpi/remote_138.png
deleted file mode 100644
index 6dfefb0934d74..0000000000000
Binary files a/packages/SystemUI/res/drawable-xhdpi/remote_138.png and /dev/null differ
diff --git a/packages/SystemUI/res/drawable-xhdpi/remote_139.png b/packages/SystemUI/res/drawable-xhdpi/remote_139.png
deleted file mode 100644
index 1acfdd6fbf50a..0000000000000
Binary files a/packages/SystemUI/res/drawable-xhdpi/remote_139.png and /dev/null differ
diff --git a/packages/SystemUI/res/drawable-xhdpi/remote_14.png b/packages/SystemUI/res/drawable-xhdpi/remote_14.png
deleted file mode 100644
index a503cdf2f54ea..0000000000000
Binary files a/packages/SystemUI/res/drawable-xhdpi/remote_14.png and /dev/null differ
diff --git a/packages/SystemUI/res/drawable-xhdpi/remote_140.png b/packages/SystemUI/res/drawable-xhdpi/remote_140.png
deleted file mode 100644
index 70d27c18f0ca0..0000000000000
Binary files a/packages/SystemUI/res/drawable-xhdpi/remote_140.png and /dev/null differ
diff --git a/packages/SystemUI/res/drawable-xhdpi/remote_141.png b/packages/SystemUI/res/drawable-xhdpi/remote_141.png
deleted file mode 100644
index d523a0c2c754f..0000000000000
Binary files a/packages/SystemUI/res/drawable-xhdpi/remote_141.png and /dev/null differ
diff --git a/packages/SystemUI/res/drawable-xhdpi/remote_142.png b/packages/SystemUI/res/drawable-xhdpi/remote_142.png
deleted file mode 100644
index ed6a65d1b9e1e..0000000000000
Binary files a/packages/SystemUI/res/drawable-xhdpi/remote_142.png and /dev/null differ
diff --git a/packages/SystemUI/res/drawable-xhdpi/remote_143.png b/packages/SystemUI/res/drawable-xhdpi/remote_143.png
deleted file mode 100644
index 9b048e693d4dc..0000000000000
Binary files a/packages/SystemUI/res/drawable-xhdpi/remote_143.png and /dev/null differ
diff --git a/packages/SystemUI/res/drawable-xhdpi/remote_144.png b/packages/SystemUI/res/drawable-xhdpi/remote_144.png
deleted file mode 100644
index 9e2337d157355..0000000000000
Binary files a/packages/SystemUI/res/drawable-xhdpi/remote_144.png and /dev/null differ
diff --git a/packages/SystemUI/res/drawable-xhdpi/remote_145.png b/packages/SystemUI/res/drawable-xhdpi/remote_145.png
deleted file mode 100644
index 3f30629c6715b..0000000000000
Binary files a/packages/SystemUI/res/drawable-xhdpi/remote_145.png and /dev/null differ
diff --git a/packages/SystemUI/res/drawable-xhdpi/remote_146.png b/packages/SystemUI/res/drawable-xhdpi/remote_146.png
deleted file mode 100644
index 1288039fe4fb7..0000000000000
Binary files a/packages/SystemUI/res/drawable-xhdpi/remote_146.png and /dev/null differ
diff --git a/packages/SystemUI/res/drawable-xhdpi/remote_147.png b/packages/SystemUI/res/drawable-xhdpi/remote_147.png
deleted file mode 100644
index d060539088efc..0000000000000
Binary files a/packages/SystemUI/res/drawable-xhdpi/remote_147.png and /dev/null differ
diff --git a/packages/SystemUI/res/drawable-xhdpi/remote_148.png b/packages/SystemUI/res/drawable-xhdpi/remote_148.png
deleted file mode 100644
index 5be839d42dfec..0000000000000
Binary files a/packages/SystemUI/res/drawable-xhdpi/remote_148.png and /dev/null differ
diff --git a/packages/SystemUI/res/drawable-xhdpi/remote_149.png b/packages/SystemUI/res/drawable-xhdpi/remote_149.png
deleted file mode 100644
index 39d31bad5af71..0000000000000
Binary files a/packages/SystemUI/res/drawable-xhdpi/remote_149.png and /dev/null differ
diff --git a/packages/SystemUI/res/drawable-xhdpi/remote_15.png b/packages/SystemUI/res/drawable-xhdpi/remote_15.png
deleted file mode 100644
index 56955952ebe1e..0000000000000
Binary files a/packages/SystemUI/res/drawable-xhdpi/remote_15.png and /dev/null differ
diff --git a/packages/SystemUI/res/drawable-xhdpi/remote_150.png b/packages/SystemUI/res/drawable-xhdpi/remote_150.png
deleted file mode 100644
index ec2667c2c3d3e..0000000000000
Binary files a/packages/SystemUI/res/drawable-xhdpi/remote_150.png and /dev/null differ
diff --git a/packages/SystemUI/res/drawable-xhdpi/remote_151.png b/packages/SystemUI/res/drawable-xhdpi/remote_151.png
deleted file mode 100644
index ec2667c2c3d3e..0000000000000
Binary files a/packages/SystemUI/res/drawable-xhdpi/remote_151.png and /dev/null differ
diff --git a/packages/SystemUI/res/drawable-xhdpi/remote_152.png b/packages/SystemUI/res/drawable-xhdpi/remote_152.png
deleted file mode 100644
index a5d58c8ff7b43..0000000000000
Binary files a/packages/SystemUI/res/drawable-xhdpi/remote_152.png and /dev/null differ
diff --git a/packages/SystemUI/res/drawable-xhdpi/remote_153.png b/packages/SystemUI/res/drawable-xhdpi/remote_153.png
deleted file mode 100644
index a5d58c8ff7b43..0000000000000
Binary files a/packages/SystemUI/res/drawable-xhdpi/remote_153.png and /dev/null differ
diff --git a/packages/SystemUI/res/drawable-xhdpi/remote_154.png b/packages/SystemUI/res/drawable-xhdpi/remote_154.png
deleted file mode 100644
index a5d58c8ff7b43..0000000000000
Binary files a/packages/SystemUI/res/drawable-xhdpi/remote_154.png and /dev/null differ
diff --git a/packages/SystemUI/res/drawable-xhdpi/remote_155.png b/packages/SystemUI/res/drawable-xhdpi/remote_155.png
deleted file mode 100644
index 793d41179a18b..0000000000000
Binary files a/packages/SystemUI/res/drawable-xhdpi/remote_155.png and /dev/null differ
diff --git a/packages/SystemUI/res/drawable-xhdpi/remote_156.png b/packages/SystemUI/res/drawable-xhdpi/remote_156.png
deleted file mode 100644
index 793d41179a18b..0000000000000
Binary files a/packages/SystemUI/res/drawable-xhdpi/remote_156.png and /dev/null differ
diff --git a/packages/SystemUI/res/drawable-xhdpi/remote_157.png b/packages/SystemUI/res/drawable-xhdpi/remote_157.png
deleted file mode 100644
index f9d6cdc166f37..0000000000000
Binary files a/packages/SystemUI/res/drawable-xhdpi/remote_157.png and /dev/null differ
diff --git a/packages/SystemUI/res/drawable-xhdpi/remote_158.png b/packages/SystemUI/res/drawable-xhdpi/remote_158.png
deleted file mode 100644
index da8d5d79f1ed6..0000000000000
Binary files a/packages/SystemUI/res/drawable-xhdpi/remote_158.png and /dev/null differ
diff --git a/packages/SystemUI/res/drawable-xhdpi/remote_159.png b/packages/SystemUI/res/drawable-xhdpi/remote_159.png
deleted file mode 100644
index 1e0b097db1781..0000000000000
Binary files a/packages/SystemUI/res/drawable-xhdpi/remote_159.png and /dev/null differ
diff --git a/packages/SystemUI/res/drawable-xhdpi/remote_16.png b/packages/SystemUI/res/drawable-xhdpi/remote_16.png
deleted file mode 100644
index 4ae106cc45d69..0000000000000
Binary files a/packages/SystemUI/res/drawable-xhdpi/remote_16.png and /dev/null differ
diff --git a/packages/SystemUI/res/drawable-xhdpi/remote_160.png b/packages/SystemUI/res/drawable-xhdpi/remote_160.png
deleted file mode 100644
index 8aa68ad787834..0000000000000
Binary files a/packages/SystemUI/res/drawable-xhdpi/remote_160.png and /dev/null differ
diff --git a/packages/SystemUI/res/drawable-xhdpi/remote_161.png b/packages/SystemUI/res/drawable-xhdpi/remote_161.png
deleted file mode 100644
index e49fdd9c71ba2..0000000000000
Binary files a/packages/SystemUI/res/drawable-xhdpi/remote_161.png and /dev/null differ
diff --git a/packages/SystemUI/res/drawable-xhdpi/remote_162.png b/packages/SystemUI/res/drawable-xhdpi/remote_162.png
deleted file mode 100644
index 69257a072b4a1..0000000000000
Binary files a/packages/SystemUI/res/drawable-xhdpi/remote_162.png and /dev/null differ
diff --git a/packages/SystemUI/res/drawable-xhdpi/remote_163.png b/packages/SystemUI/res/drawable-xhdpi/remote_163.png
deleted file mode 100644
index 8f0c3d5f261e7..0000000000000
Binary files a/packages/SystemUI/res/drawable-xhdpi/remote_163.png and /dev/null differ
diff --git a/packages/SystemUI/res/drawable-xhdpi/remote_164.png b/packages/SystemUI/res/drawable-xhdpi/remote_164.png
deleted file mode 100644
index a4c3229e80a94..0000000000000
Binary files a/packages/SystemUI/res/drawable-xhdpi/remote_164.png and /dev/null differ
diff --git a/packages/SystemUI/res/drawable-xhdpi/remote_165.png b/packages/SystemUI/res/drawable-xhdpi/remote_165.png
deleted file mode 100644
index 46fae23e534ad..0000000000000
Binary files a/packages/SystemUI/res/drawable-xhdpi/remote_165.png and /dev/null differ
diff --git a/packages/SystemUI/res/drawable-xhdpi/remote_166.png b/packages/SystemUI/res/drawable-xhdpi/remote_166.png
deleted file mode 100644
index 40d5a9b76f4ca..0000000000000
Binary files a/packages/SystemUI/res/drawable-xhdpi/remote_166.png and /dev/null differ
diff --git a/packages/SystemUI/res/drawable-xhdpi/remote_167.png b/packages/SystemUI/res/drawable-xhdpi/remote_167.png
deleted file mode 100644
index 6bd0380a3e9a6..0000000000000
Binary files a/packages/SystemUI/res/drawable-xhdpi/remote_167.png and /dev/null differ
diff --git a/packages/SystemUI/res/drawable-xhdpi/remote_168.png b/packages/SystemUI/res/drawable-xhdpi/remote_168.png
deleted file mode 100644
index 03904bf47dd4a..0000000000000
Binary files a/packages/SystemUI/res/drawable-xhdpi/remote_168.png and /dev/null differ
diff --git a/packages/SystemUI/res/drawable-xhdpi/remote_169.png b/packages/SystemUI/res/drawable-xhdpi/remote_169.png
deleted file mode 100644
index 564a1610d7777..0000000000000
Binary files a/packages/SystemUI/res/drawable-xhdpi/remote_169.png and /dev/null differ
diff --git a/packages/SystemUI/res/drawable-xhdpi/remote_17.png b/packages/SystemUI/res/drawable-xhdpi/remote_17.png
deleted file mode 100644
index 0703e1a183aa8..0000000000000
Binary files a/packages/SystemUI/res/drawable-xhdpi/remote_17.png and /dev/null differ
diff --git a/packages/SystemUI/res/drawable-xhdpi/remote_170.png b/packages/SystemUI/res/drawable-xhdpi/remote_170.png
deleted file mode 100644
index 0411f94479e26..0000000000000
Binary files a/packages/SystemUI/res/drawable-xhdpi/remote_170.png and /dev/null differ
diff --git a/packages/SystemUI/res/drawable-xhdpi/remote_171.png b/packages/SystemUI/res/drawable-xhdpi/remote_171.png
deleted file mode 100644
index ec141e92e5666..0000000000000
Binary files a/packages/SystemUI/res/drawable-xhdpi/remote_171.png and /dev/null differ
diff --git a/packages/SystemUI/res/drawable-xhdpi/remote_172.png b/packages/SystemUI/res/drawable-xhdpi/remote_172.png
deleted file mode 100644
index cb9ecaf985b0a..0000000000000
Binary files a/packages/SystemUI/res/drawable-xhdpi/remote_172.png and /dev/null differ
diff --git a/packages/SystemUI/res/drawable-xhdpi/remote_173.png b/packages/SystemUI/res/drawable-xhdpi/remote_173.png
deleted file mode 100644
index 484ee5128bb82..0000000000000
Binary files a/packages/SystemUI/res/drawable-xhdpi/remote_173.png and /dev/null differ
diff --git a/packages/SystemUI/res/drawable-xhdpi/remote_174.png b/packages/SystemUI/res/drawable-xhdpi/remote_174.png
deleted file mode 100644
index 85a31351c8000..0000000000000
Binary files a/packages/SystemUI/res/drawable-xhdpi/remote_174.png and /dev/null differ
diff --git a/packages/SystemUI/res/drawable-xhdpi/remote_175.png b/packages/SystemUI/res/drawable-xhdpi/remote_175.png
deleted file mode 100644
index edd65074519d5..0000000000000
Binary files a/packages/SystemUI/res/drawable-xhdpi/remote_175.png and /dev/null differ
diff --git a/packages/SystemUI/res/drawable-xhdpi/remote_176.png b/packages/SystemUI/res/drawable-xhdpi/remote_176.png
deleted file mode 100644
index d95a68b3020fd..0000000000000
Binary files a/packages/SystemUI/res/drawable-xhdpi/remote_176.png and /dev/null differ
diff --git a/packages/SystemUI/res/drawable-xhdpi/remote_177.png b/packages/SystemUI/res/drawable-xhdpi/remote_177.png
deleted file mode 100644
index 305641f8d83ca..0000000000000
Binary files a/packages/SystemUI/res/drawable-xhdpi/remote_177.png and /dev/null differ
diff --git a/packages/SystemUI/res/drawable-xhdpi/remote_178.png b/packages/SystemUI/res/drawable-xhdpi/remote_178.png
deleted file mode 100644
index 59de0e58446a0..0000000000000
Binary files a/packages/SystemUI/res/drawable-xhdpi/remote_178.png and /dev/null differ
diff --git a/packages/SystemUI/res/drawable-xhdpi/remote_179.png b/packages/SystemUI/res/drawable-xhdpi/remote_179.png
deleted file mode 100644
index 414e548c17f6f..0000000000000
Binary files a/packages/SystemUI/res/drawable-xhdpi/remote_179.png and /dev/null differ
diff --git a/packages/SystemUI/res/drawable-xhdpi/remote_18.png b/packages/SystemUI/res/drawable-xhdpi/remote_18.png
deleted file mode 100644
index 74df1e4520d5b..0000000000000
Binary files a/packages/SystemUI/res/drawable-xhdpi/remote_18.png and /dev/null differ
diff --git a/packages/SystemUI/res/drawable-xhdpi/remote_180.png b/packages/SystemUI/res/drawable-xhdpi/remote_180.png
deleted file mode 100644
index b5d925c0997ee..0000000000000
Binary files a/packages/SystemUI/res/drawable-xhdpi/remote_180.png and /dev/null differ
diff --git a/packages/SystemUI/res/drawable-xhdpi/remote_181.png b/packages/SystemUI/res/drawable-xhdpi/remote_181.png
deleted file mode 100644
index e8a71278cc03b..0000000000000
Binary files a/packages/SystemUI/res/drawable-xhdpi/remote_181.png and /dev/null differ
diff --git a/packages/SystemUI/res/drawable-xhdpi/remote_182.png b/packages/SystemUI/res/drawable-xhdpi/remote_182.png
deleted file mode 100644
index 29c70375de425..0000000000000
Binary files a/packages/SystemUI/res/drawable-xhdpi/remote_182.png and /dev/null differ
diff --git a/packages/SystemUI/res/drawable-xhdpi/remote_183.png b/packages/SystemUI/res/drawable-xhdpi/remote_183.png
deleted file mode 100644
index 9491d9467d2d3..0000000000000
Binary files a/packages/SystemUI/res/drawable-xhdpi/remote_183.png and /dev/null differ
diff --git a/packages/SystemUI/res/drawable-xhdpi/remote_184.png b/packages/SystemUI/res/drawable-xhdpi/remote_184.png
deleted file mode 100644
index 4aa0e3253a830..0000000000000
Binary files a/packages/SystemUI/res/drawable-xhdpi/remote_184.png and /dev/null differ
diff --git a/packages/SystemUI/res/drawable-xhdpi/remote_185.png b/packages/SystemUI/res/drawable-xhdpi/remote_185.png
deleted file mode 100644
index 2a0dde86123de..0000000000000
Binary files a/packages/SystemUI/res/drawable-xhdpi/remote_185.png and /dev/null differ
diff --git a/packages/SystemUI/res/drawable-xhdpi/remote_186.png b/packages/SystemUI/res/drawable-xhdpi/remote_186.png
deleted file mode 100644
index 5bda52e3b0896..0000000000000
Binary files a/packages/SystemUI/res/drawable-xhdpi/remote_186.png and /dev/null differ
diff --git a/packages/SystemUI/res/drawable-xhdpi/remote_187.png b/packages/SystemUI/res/drawable-xhdpi/remote_187.png
deleted file mode 100644
index 5bda52e3b0896..0000000000000
Binary files a/packages/SystemUI/res/drawable-xhdpi/remote_187.png and /dev/null differ
diff --git a/packages/SystemUI/res/drawable-xhdpi/remote_188.png b/packages/SystemUI/res/drawable-xhdpi/remote_188.png
deleted file mode 100644
index 5bda52e3b0896..0000000000000
Binary files a/packages/SystemUI/res/drawable-xhdpi/remote_188.png and /dev/null differ
diff --git a/packages/SystemUI/res/drawable-xhdpi/remote_189.png b/packages/SystemUI/res/drawable-xhdpi/remote_189.png
deleted file mode 100644
index 5bda52e3b0896..0000000000000
Binary files a/packages/SystemUI/res/drawable-xhdpi/remote_189.png and /dev/null differ
diff --git a/packages/SystemUI/res/drawable-xhdpi/remote_19.png b/packages/SystemUI/res/drawable-xhdpi/remote_19.png
deleted file mode 100644
index 222ea31194afc..0000000000000
Binary files a/packages/SystemUI/res/drawable-xhdpi/remote_19.png and /dev/null differ
diff --git a/packages/SystemUI/res/drawable-xhdpi/remote_190.png b/packages/SystemUI/res/drawable-xhdpi/remote_190.png
deleted file mode 100644
index 5bda52e3b0896..0000000000000
Binary files a/packages/SystemUI/res/drawable-xhdpi/remote_190.png and /dev/null differ
diff --git a/packages/SystemUI/res/drawable-xhdpi/remote_191.png b/packages/SystemUI/res/drawable-xhdpi/remote_191.png
deleted file mode 100644
index 5bda52e3b0896..0000000000000
Binary files a/packages/SystemUI/res/drawable-xhdpi/remote_191.png and /dev/null differ
diff --git a/packages/SystemUI/res/drawable-xhdpi/remote_192.png b/packages/SystemUI/res/drawable-xhdpi/remote_192.png
deleted file mode 100644
index 5bda52e3b0896..0000000000000
Binary files a/packages/SystemUI/res/drawable-xhdpi/remote_192.png and /dev/null differ
diff --git a/packages/SystemUI/res/drawable-xhdpi/remote_193.png b/packages/SystemUI/res/drawable-xhdpi/remote_193.png
deleted file mode 100644
index 5bda52e3b0896..0000000000000
Binary files a/packages/SystemUI/res/drawable-xhdpi/remote_193.png and /dev/null differ
diff --git a/packages/SystemUI/res/drawable-xhdpi/remote_194.png b/packages/SystemUI/res/drawable-xhdpi/remote_194.png
deleted file mode 100644
index 5bda52e3b0896..0000000000000
Binary files a/packages/SystemUI/res/drawable-xhdpi/remote_194.png and /dev/null differ
diff --git a/packages/SystemUI/res/drawable-xhdpi/remote_195.png b/packages/SystemUI/res/drawable-xhdpi/remote_195.png
deleted file mode 100644
index 5bda52e3b0896..0000000000000
Binary files a/packages/SystemUI/res/drawable-xhdpi/remote_195.png and /dev/null differ
diff --git a/packages/SystemUI/res/drawable-xhdpi/remote_196.png b/packages/SystemUI/res/drawable-xhdpi/remote_196.png
deleted file mode 100644
index 5bda52e3b0896..0000000000000
Binary files a/packages/SystemUI/res/drawable-xhdpi/remote_196.png and /dev/null differ
diff --git a/packages/SystemUI/res/drawable-xhdpi/remote_197.png b/packages/SystemUI/res/drawable-xhdpi/remote_197.png
deleted file mode 100644
index 5bda52e3b0896..0000000000000
Binary files a/packages/SystemUI/res/drawable-xhdpi/remote_197.png and /dev/null differ
diff --git a/packages/SystemUI/res/drawable-xhdpi/remote_198.png b/packages/SystemUI/res/drawable-xhdpi/remote_198.png
deleted file mode 100644
index 5bda52e3b0896..0000000000000
Binary files a/packages/SystemUI/res/drawable-xhdpi/remote_198.png and /dev/null differ
diff --git a/packages/SystemUI/res/drawable-xhdpi/remote_199.png b/packages/SystemUI/res/drawable-xhdpi/remote_199.png
deleted file mode 100644
index 5bda52e3b0896..0000000000000
Binary files a/packages/SystemUI/res/drawable-xhdpi/remote_199.png and /dev/null differ
diff --git a/packages/SystemUI/res/drawable-xhdpi/remote_2.png b/packages/SystemUI/res/drawable-xhdpi/remote_2.png
deleted file mode 100644
index fb3f7ef1364ca..0000000000000
Binary files a/packages/SystemUI/res/drawable-xhdpi/remote_2.png and /dev/null differ
diff --git a/packages/SystemUI/res/drawable-xhdpi/remote_20.png b/packages/SystemUI/res/drawable-xhdpi/remote_20.png
deleted file mode 100644
index 646587c3e29ca..0000000000000
Binary files a/packages/SystemUI/res/drawable-xhdpi/remote_20.png and /dev/null differ
diff --git a/packages/SystemUI/res/drawable-xhdpi/remote_200.png b/packages/SystemUI/res/drawable-xhdpi/remote_200.png
deleted file mode 100644
index 5bda52e3b0896..0000000000000
Binary files a/packages/SystemUI/res/drawable-xhdpi/remote_200.png and /dev/null differ
diff --git a/packages/SystemUI/res/drawable-xhdpi/remote_201.png b/packages/SystemUI/res/drawable-xhdpi/remote_201.png
deleted file mode 100644
index 5bda52e3b0896..0000000000000
Binary files a/packages/SystemUI/res/drawable-xhdpi/remote_201.png and /dev/null differ
diff --git a/packages/SystemUI/res/drawable-xhdpi/remote_202.png b/packages/SystemUI/res/drawable-xhdpi/remote_202.png
deleted file mode 100644
index 5bda52e3b0896..0000000000000
Binary files a/packages/SystemUI/res/drawable-xhdpi/remote_202.png and /dev/null differ
diff --git a/packages/SystemUI/res/drawable-xhdpi/remote_203.png b/packages/SystemUI/res/drawable-xhdpi/remote_203.png
deleted file mode 100644
index 5bda52e3b0896..0000000000000
Binary files a/packages/SystemUI/res/drawable-xhdpi/remote_203.png and /dev/null differ
diff --git a/packages/SystemUI/res/drawable-xhdpi/remote_204.png b/packages/SystemUI/res/drawable-xhdpi/remote_204.png
deleted file mode 100644
index 5bda52e3b0896..0000000000000
Binary files a/packages/SystemUI/res/drawable-xhdpi/remote_204.png and /dev/null differ
diff --git a/packages/SystemUI/res/drawable-xhdpi/remote_205.png b/packages/SystemUI/res/drawable-xhdpi/remote_205.png
deleted file mode 100644
index 5bda52e3b0896..0000000000000
Binary files a/packages/SystemUI/res/drawable-xhdpi/remote_205.png and /dev/null differ
diff --git a/packages/SystemUI/res/drawable-xhdpi/remote_206.png b/packages/SystemUI/res/drawable-xhdpi/remote_206.png
deleted file mode 100644
index 5bda52e3b0896..0000000000000
Binary files a/packages/SystemUI/res/drawable-xhdpi/remote_206.png and /dev/null differ
diff --git a/packages/SystemUI/res/drawable-xhdpi/remote_207.png b/packages/SystemUI/res/drawable-xhdpi/remote_207.png
deleted file mode 100644
index 5bda52e3b0896..0000000000000
Binary files a/packages/SystemUI/res/drawable-xhdpi/remote_207.png and /dev/null differ
diff --git a/packages/SystemUI/res/drawable-xhdpi/remote_208.png b/packages/SystemUI/res/drawable-xhdpi/remote_208.png
deleted file mode 100644
index 5bda52e3b0896..0000000000000
Binary files a/packages/SystemUI/res/drawable-xhdpi/remote_208.png and /dev/null differ
diff --git a/packages/SystemUI/res/drawable-xhdpi/remote_209.png b/packages/SystemUI/res/drawable-xhdpi/remote_209.png
deleted file mode 100644
index 5bda52e3b0896..0000000000000
Binary files a/packages/SystemUI/res/drawable-xhdpi/remote_209.png and /dev/null differ
diff --git a/packages/SystemUI/res/drawable-xhdpi/remote_21.png b/packages/SystemUI/res/drawable-xhdpi/remote_21.png
deleted file mode 100644
index 5858ba92ce7a1..0000000000000
Binary files a/packages/SystemUI/res/drawable-xhdpi/remote_21.png and /dev/null differ
diff --git a/packages/SystemUI/res/drawable-xhdpi/remote_210.png b/packages/SystemUI/res/drawable-xhdpi/remote_210.png
deleted file mode 100644
index 5bda52e3b0896..0000000000000
Binary files a/packages/SystemUI/res/drawable-xhdpi/remote_210.png and /dev/null differ
diff --git a/packages/SystemUI/res/drawable-xhdpi/remote_211.png b/packages/SystemUI/res/drawable-xhdpi/remote_211.png
deleted file mode 100644
index 5bda52e3b0896..0000000000000
Binary files a/packages/SystemUI/res/drawable-xhdpi/remote_211.png and /dev/null differ
diff --git a/packages/SystemUI/res/drawable-xhdpi/remote_212.png b/packages/SystemUI/res/drawable-xhdpi/remote_212.png
deleted file mode 100644
index 5bda52e3b0896..0000000000000
Binary files a/packages/SystemUI/res/drawable-xhdpi/remote_212.png and /dev/null differ
diff --git a/packages/SystemUI/res/drawable-xhdpi/remote_213.png b/packages/SystemUI/res/drawable-xhdpi/remote_213.png
deleted file mode 100644
index 5bda52e3b0896..0000000000000
Binary files a/packages/SystemUI/res/drawable-xhdpi/remote_213.png and /dev/null differ
diff --git a/packages/SystemUI/res/drawable-xhdpi/remote_214.png b/packages/SystemUI/res/drawable-xhdpi/remote_214.png
deleted file mode 100644
index 5bda52e3b0896..0000000000000
Binary files a/packages/SystemUI/res/drawable-xhdpi/remote_214.png and /dev/null differ
diff --git a/packages/SystemUI/res/drawable-xhdpi/remote_215.png b/packages/SystemUI/res/drawable-xhdpi/remote_215.png
deleted file mode 100644
index 5bda52e3b0896..0000000000000
Binary files a/packages/SystemUI/res/drawable-xhdpi/remote_215.png and /dev/null differ
diff --git a/packages/SystemUI/res/drawable-xhdpi/remote_216.png b/packages/SystemUI/res/drawable-xhdpi/remote_216.png
deleted file mode 100644
index 5bda52e3b0896..0000000000000
Binary files a/packages/SystemUI/res/drawable-xhdpi/remote_216.png and /dev/null differ
diff --git a/packages/SystemUI/res/drawable-xhdpi/remote_217.png b/packages/SystemUI/res/drawable-xhdpi/remote_217.png
deleted file mode 100644
index 5bda52e3b0896..0000000000000
Binary files a/packages/SystemUI/res/drawable-xhdpi/remote_217.png and /dev/null differ
diff --git a/packages/SystemUI/res/drawable-xhdpi/remote_218.png b/packages/SystemUI/res/drawable-xhdpi/remote_218.png
deleted file mode 100644
index 5bda52e3b0896..0000000000000
Binary files a/packages/SystemUI/res/drawable-xhdpi/remote_218.png and /dev/null differ
diff --git a/packages/SystemUI/res/drawable-xhdpi/remote_219.png b/packages/SystemUI/res/drawable-xhdpi/remote_219.png
deleted file mode 100644
index 5bda52e3b0896..0000000000000
Binary files a/packages/SystemUI/res/drawable-xhdpi/remote_219.png and /dev/null differ
diff --git a/packages/SystemUI/res/drawable-xhdpi/remote_22.png b/packages/SystemUI/res/drawable-xhdpi/remote_22.png
deleted file mode 100644
index 197480232386e..0000000000000
Binary files a/packages/SystemUI/res/drawable-xhdpi/remote_22.png and /dev/null differ
diff --git a/packages/SystemUI/res/drawable-xhdpi/remote_220.png b/packages/SystemUI/res/drawable-xhdpi/remote_220.png
deleted file mode 100644
index 5bda52e3b0896..0000000000000
Binary files a/packages/SystemUI/res/drawable-xhdpi/remote_220.png and /dev/null differ
diff --git a/packages/SystemUI/res/drawable-xhdpi/remote_221.png b/packages/SystemUI/res/drawable-xhdpi/remote_221.png
deleted file mode 100644
index 5bda52e3b0896..0000000000000
Binary files a/packages/SystemUI/res/drawable-xhdpi/remote_221.png and /dev/null differ
diff --git a/packages/SystemUI/res/drawable-xhdpi/remote_222.png b/packages/SystemUI/res/drawable-xhdpi/remote_222.png
deleted file mode 100644
index 5bda52e3b0896..0000000000000
Binary files a/packages/SystemUI/res/drawable-xhdpi/remote_222.png and /dev/null differ
diff --git a/packages/SystemUI/res/drawable-xhdpi/remote_223.png b/packages/SystemUI/res/drawable-xhdpi/remote_223.png
deleted file mode 100644
index 5bda52e3b0896..0000000000000
Binary files a/packages/SystemUI/res/drawable-xhdpi/remote_223.png and /dev/null differ
diff --git a/packages/SystemUI/res/drawable-xhdpi/remote_224.png b/packages/SystemUI/res/drawable-xhdpi/remote_224.png
deleted file mode 100644
index 5bda52e3b0896..0000000000000
Binary files a/packages/SystemUI/res/drawable-xhdpi/remote_224.png and /dev/null differ
diff --git a/packages/SystemUI/res/drawable-xhdpi/remote_225.png b/packages/SystemUI/res/drawable-xhdpi/remote_225.png
deleted file mode 100644
index 5bda52e3b0896..0000000000000
Binary files a/packages/SystemUI/res/drawable-xhdpi/remote_225.png and /dev/null differ
diff --git a/packages/SystemUI/res/drawable-xhdpi/remote_226.png b/packages/SystemUI/res/drawable-xhdpi/remote_226.png
deleted file mode 100644
index 5bda52e3b0896..0000000000000
Binary files a/packages/SystemUI/res/drawable-xhdpi/remote_226.png and /dev/null differ
diff --git a/packages/SystemUI/res/drawable-xhdpi/remote_227.png b/packages/SystemUI/res/drawable-xhdpi/remote_227.png
deleted file mode 100644
index 5bda52e3b0896..0000000000000
Binary files a/packages/SystemUI/res/drawable-xhdpi/remote_227.png and /dev/null differ
diff --git a/packages/SystemUI/res/drawable-xhdpi/remote_228.png b/packages/SystemUI/res/drawable-xhdpi/remote_228.png
deleted file mode 100644
index 5bda52e3b0896..0000000000000
Binary files a/packages/SystemUI/res/drawable-xhdpi/remote_228.png and /dev/null differ
diff --git a/packages/SystemUI/res/drawable-xhdpi/remote_229.png b/packages/SystemUI/res/drawable-xhdpi/remote_229.png
deleted file mode 100644
index 5bda52e3b0896..0000000000000
Binary files a/packages/SystemUI/res/drawable-xhdpi/remote_229.png and /dev/null differ
diff --git a/packages/SystemUI/res/drawable-xhdpi/remote_23.png b/packages/SystemUI/res/drawable-xhdpi/remote_23.png
deleted file mode 100644
index 96b7c3546d76a..0000000000000
Binary files a/packages/SystemUI/res/drawable-xhdpi/remote_23.png and /dev/null differ
diff --git a/packages/SystemUI/res/drawable-xhdpi/remote_230.png b/packages/SystemUI/res/drawable-xhdpi/remote_230.png
deleted file mode 100644
index 5bda52e3b0896..0000000000000
Binary files a/packages/SystemUI/res/drawable-xhdpi/remote_230.png and /dev/null differ
diff --git a/packages/SystemUI/res/drawable-xhdpi/remote_231.png b/packages/SystemUI/res/drawable-xhdpi/remote_231.png
deleted file mode 100644
index 5bda52e3b0896..0000000000000
Binary files a/packages/SystemUI/res/drawable-xhdpi/remote_231.png and /dev/null differ
diff --git a/packages/SystemUI/res/drawable-xhdpi/remote_232.png b/packages/SystemUI/res/drawable-xhdpi/remote_232.png
deleted file mode 100644
index 5bda52e3b0896..0000000000000
Binary files a/packages/SystemUI/res/drawable-xhdpi/remote_232.png and /dev/null differ
diff --git a/packages/SystemUI/res/drawable-xhdpi/remote_233.png b/packages/SystemUI/res/drawable-xhdpi/remote_233.png
deleted file mode 100644
index 5bda52e3b0896..0000000000000
Binary files a/packages/SystemUI/res/drawable-xhdpi/remote_233.png and /dev/null differ
diff --git a/packages/SystemUI/res/drawable-xhdpi/remote_234.png b/packages/SystemUI/res/drawable-xhdpi/remote_234.png
deleted file mode 100644
index 5bda52e3b0896..0000000000000
Binary files a/packages/SystemUI/res/drawable-xhdpi/remote_234.png and /dev/null differ
diff --git a/packages/SystemUI/res/drawable-xhdpi/remote_235.png b/packages/SystemUI/res/drawable-xhdpi/remote_235.png
deleted file mode 100644
index 5bda52e3b0896..0000000000000
Binary files a/packages/SystemUI/res/drawable-xhdpi/remote_235.png and /dev/null differ
diff --git a/packages/SystemUI/res/drawable-xhdpi/remote_236.png b/packages/SystemUI/res/drawable-xhdpi/remote_236.png
deleted file mode 100644
index 5bda52e3b0896..0000000000000
Binary files a/packages/SystemUI/res/drawable-xhdpi/remote_236.png and /dev/null differ
diff --git a/packages/SystemUI/res/drawable-xhdpi/remote_237.png b/packages/SystemUI/res/drawable-xhdpi/remote_237.png
deleted file mode 100644
index 5bda52e3b0896..0000000000000
Binary files a/packages/SystemUI/res/drawable-xhdpi/remote_237.png and /dev/null differ
diff --git a/packages/SystemUI/res/drawable-xhdpi/remote_238.png b/packages/SystemUI/res/drawable-xhdpi/remote_238.png
deleted file mode 100644
index 5bda52e3b0896..0000000000000
Binary files a/packages/SystemUI/res/drawable-xhdpi/remote_238.png and /dev/null differ
diff --git a/packages/SystemUI/res/drawable-xhdpi/remote_239.png b/packages/SystemUI/res/drawable-xhdpi/remote_239.png
deleted file mode 100644
index 5bda52e3b0896..0000000000000
Binary files a/packages/SystemUI/res/drawable-xhdpi/remote_239.png and /dev/null differ
diff --git a/packages/SystemUI/res/drawable-xhdpi/remote_24.png b/packages/SystemUI/res/drawable-xhdpi/remote_24.png
deleted file mode 100644
index 0437200d773ab..0000000000000
Binary files a/packages/SystemUI/res/drawable-xhdpi/remote_24.png and /dev/null differ
diff --git a/packages/SystemUI/res/drawable-xhdpi/remote_25.png b/packages/SystemUI/res/drawable-xhdpi/remote_25.png
deleted file mode 100644
index 60b0f154369ca..0000000000000
Binary files a/packages/SystemUI/res/drawable-xhdpi/remote_25.png and /dev/null differ
diff --git a/packages/SystemUI/res/drawable-xhdpi/remote_26.png b/packages/SystemUI/res/drawable-xhdpi/remote_26.png
deleted file mode 100644
index c34ed97b5c93d..0000000000000
Binary files a/packages/SystemUI/res/drawable-xhdpi/remote_26.png and /dev/null differ
diff --git a/packages/SystemUI/res/drawable-xhdpi/remote_27.png b/packages/SystemUI/res/drawable-xhdpi/remote_27.png
deleted file mode 100644
index 1a83664c5ebc8..0000000000000
Binary files a/packages/SystemUI/res/drawable-xhdpi/remote_27.png and /dev/null differ
diff --git a/packages/SystemUI/res/drawable-xhdpi/remote_28.png b/packages/SystemUI/res/drawable-xhdpi/remote_28.png
deleted file mode 100644
index a3685ad396aba..0000000000000
Binary files a/packages/SystemUI/res/drawable-xhdpi/remote_28.png and /dev/null differ
diff --git a/packages/SystemUI/res/drawable-xhdpi/remote_29.png b/packages/SystemUI/res/drawable-xhdpi/remote_29.png
deleted file mode 100644
index f7135eb8321ae..0000000000000
Binary files a/packages/SystemUI/res/drawable-xhdpi/remote_29.png and /dev/null differ
diff --git a/packages/SystemUI/res/drawable-xhdpi/remote_3.png b/packages/SystemUI/res/drawable-xhdpi/remote_3.png
deleted file mode 100644
index 937da65ea9a13..0000000000000
Binary files a/packages/SystemUI/res/drawable-xhdpi/remote_3.png and /dev/null differ
diff --git a/packages/SystemUI/res/drawable-xhdpi/remote_30.png b/packages/SystemUI/res/drawable-xhdpi/remote_30.png
deleted file mode 100644
index 718cf524f1512..0000000000000
Binary files a/packages/SystemUI/res/drawable-xhdpi/remote_30.png and /dev/null differ
diff --git a/packages/SystemUI/res/drawable-xhdpi/remote_31.png b/packages/SystemUI/res/drawable-xhdpi/remote_31.png
deleted file mode 100644
index c0b55df68f759..0000000000000
Binary files a/packages/SystemUI/res/drawable-xhdpi/remote_31.png and /dev/null differ
diff --git a/packages/SystemUI/res/drawable-xhdpi/remote_32.png b/packages/SystemUI/res/drawable-xhdpi/remote_32.png
deleted file mode 100644
index 7a1ce9fd43c6d..0000000000000
Binary files a/packages/SystemUI/res/drawable-xhdpi/remote_32.png and /dev/null differ
diff --git a/packages/SystemUI/res/drawable-xhdpi/remote_33.png b/packages/SystemUI/res/drawable-xhdpi/remote_33.png
deleted file mode 100644
index 5428bcf327ef0..0000000000000
Binary files a/packages/SystemUI/res/drawable-xhdpi/remote_33.png and /dev/null differ
diff --git a/packages/SystemUI/res/drawable-xhdpi/remote_34.png b/packages/SystemUI/res/drawable-xhdpi/remote_34.png
deleted file mode 100644
index 264efe87f164a..0000000000000
Binary files a/packages/SystemUI/res/drawable-xhdpi/remote_34.png and /dev/null differ
diff --git a/packages/SystemUI/res/drawable-xhdpi/remote_35.png b/packages/SystemUI/res/drawable-xhdpi/remote_35.png
deleted file mode 100644
index a5c450f4bab62..0000000000000
Binary files a/packages/SystemUI/res/drawable-xhdpi/remote_35.png and /dev/null differ
diff --git a/packages/SystemUI/res/drawable-xhdpi/remote_36.png b/packages/SystemUI/res/drawable-xhdpi/remote_36.png
deleted file mode 100644
index 3e469e4a3b36d..0000000000000
Binary files a/packages/SystemUI/res/drawable-xhdpi/remote_36.png and /dev/null differ
diff --git a/packages/SystemUI/res/drawable-xhdpi/remote_37.png b/packages/SystemUI/res/drawable-xhdpi/remote_37.png
deleted file mode 100644
index 124ebe4f1599a..0000000000000
Binary files a/packages/SystemUI/res/drawable-xhdpi/remote_37.png and /dev/null differ
diff --git a/packages/SystemUI/res/drawable-xhdpi/remote_38.png b/packages/SystemUI/res/drawable-xhdpi/remote_38.png
deleted file mode 100644
index b2b48448c568d..0000000000000
Binary files a/packages/SystemUI/res/drawable-xhdpi/remote_38.png and /dev/null differ
diff --git a/packages/SystemUI/res/drawable-xhdpi/remote_39.png b/packages/SystemUI/res/drawable-xhdpi/remote_39.png
deleted file mode 100644
index a6d1733b1d6bc..0000000000000
Binary files a/packages/SystemUI/res/drawable-xhdpi/remote_39.png and /dev/null differ
diff --git a/packages/SystemUI/res/drawable-xhdpi/remote_4.png b/packages/SystemUI/res/drawable-xhdpi/remote_4.png
deleted file mode 100644
index c282f406839b2..0000000000000
Binary files a/packages/SystemUI/res/drawable-xhdpi/remote_4.png and /dev/null differ
diff --git a/packages/SystemUI/res/drawable-xhdpi/remote_40.png b/packages/SystemUI/res/drawable-xhdpi/remote_40.png
deleted file mode 100644
index 4cd615c16b93d..0000000000000
Binary files a/packages/SystemUI/res/drawable-xhdpi/remote_40.png and /dev/null differ
diff --git a/packages/SystemUI/res/drawable-xhdpi/remote_41.png b/packages/SystemUI/res/drawable-xhdpi/remote_41.png
deleted file mode 100644
index c746ae0fcc827..0000000000000
Binary files a/packages/SystemUI/res/drawable-xhdpi/remote_41.png and /dev/null differ
diff --git a/packages/SystemUI/res/drawable-xhdpi/remote_42.png b/packages/SystemUI/res/drawable-xhdpi/remote_42.png
deleted file mode 100644
index a93f1984dce4e..0000000000000
Binary files a/packages/SystemUI/res/drawable-xhdpi/remote_42.png and /dev/null differ
diff --git a/packages/SystemUI/res/drawable-xhdpi/remote_43.png b/packages/SystemUI/res/drawable-xhdpi/remote_43.png
deleted file mode 100644
index 966e563e3fa24..0000000000000
Binary files a/packages/SystemUI/res/drawable-xhdpi/remote_43.png and /dev/null differ
diff --git a/packages/SystemUI/res/drawable-xhdpi/remote_44.png b/packages/SystemUI/res/drawable-xhdpi/remote_44.png
deleted file mode 100644
index beb7031cd7aaf..0000000000000
Binary files a/packages/SystemUI/res/drawable-xhdpi/remote_44.png and /dev/null differ
diff --git a/packages/SystemUI/res/drawable-xhdpi/remote_45.png b/packages/SystemUI/res/drawable-xhdpi/remote_45.png
deleted file mode 100644
index 718e1678af570..0000000000000
Binary files a/packages/SystemUI/res/drawable-xhdpi/remote_45.png and /dev/null differ
diff --git a/packages/SystemUI/res/drawable-xhdpi/remote_46.png b/packages/SystemUI/res/drawable-xhdpi/remote_46.png
deleted file mode 100644
index aa54ddbf61d14..0000000000000
Binary files a/packages/SystemUI/res/drawable-xhdpi/remote_46.png and /dev/null differ
diff --git a/packages/SystemUI/res/drawable-xhdpi/remote_47.png b/packages/SystemUI/res/drawable-xhdpi/remote_47.png
deleted file mode 100644
index 1d112707ea685..0000000000000
Binary files a/packages/SystemUI/res/drawable-xhdpi/remote_47.png and /dev/null differ
diff --git a/packages/SystemUI/res/drawable-xhdpi/remote_48.png b/packages/SystemUI/res/drawable-xhdpi/remote_48.png
deleted file mode 100644
index ab31163c9096c..0000000000000
Binary files a/packages/SystemUI/res/drawable-xhdpi/remote_48.png and /dev/null differ
diff --git a/packages/SystemUI/res/drawable-xhdpi/remote_49.png b/packages/SystemUI/res/drawable-xhdpi/remote_49.png
deleted file mode 100644
index 219b7f6454841..0000000000000
Binary files a/packages/SystemUI/res/drawable-xhdpi/remote_49.png and /dev/null differ
diff --git a/packages/SystemUI/res/drawable-xhdpi/remote_5.png b/packages/SystemUI/res/drawable-xhdpi/remote_5.png
deleted file mode 100644
index 15f69e19c75a8..0000000000000
Binary files a/packages/SystemUI/res/drawable-xhdpi/remote_5.png and /dev/null differ
diff --git a/packages/SystemUI/res/drawable-xhdpi/remote_50.png b/packages/SystemUI/res/drawable-xhdpi/remote_50.png
deleted file mode 100644
index 8a9725fb67779..0000000000000
Binary files a/packages/SystemUI/res/drawable-xhdpi/remote_50.png and /dev/null differ
diff --git a/packages/SystemUI/res/drawable-xhdpi/remote_51.png b/packages/SystemUI/res/drawable-xhdpi/remote_51.png
deleted file mode 100644
index bc839cfc7fbc5..0000000000000
Binary files a/packages/SystemUI/res/drawable-xhdpi/remote_51.png and /dev/null differ
diff --git a/packages/SystemUI/res/drawable-xhdpi/remote_52.png b/packages/SystemUI/res/drawable-xhdpi/remote_52.png
deleted file mode 100644
index 7bab6e54ad23c..0000000000000
Binary files a/packages/SystemUI/res/drawable-xhdpi/remote_52.png and /dev/null differ
diff --git a/packages/SystemUI/res/drawable-xhdpi/remote_53.png b/packages/SystemUI/res/drawable-xhdpi/remote_53.png
deleted file mode 100644
index 34ab855027f69..0000000000000
Binary files a/packages/SystemUI/res/drawable-xhdpi/remote_53.png and /dev/null differ
diff --git a/packages/SystemUI/res/drawable-xhdpi/remote_54.png b/packages/SystemUI/res/drawable-xhdpi/remote_54.png
deleted file mode 100644
index 5bd9f59afe3b2..0000000000000
Binary files a/packages/SystemUI/res/drawable-xhdpi/remote_54.png and /dev/null differ
diff --git a/packages/SystemUI/res/drawable-xhdpi/remote_55.png b/packages/SystemUI/res/drawable-xhdpi/remote_55.png
deleted file mode 100644
index 1ff17f4c0aff2..0000000000000
Binary files a/packages/SystemUI/res/drawable-xhdpi/remote_55.png and /dev/null differ
diff --git a/packages/SystemUI/res/drawable-xhdpi/remote_56.png b/packages/SystemUI/res/drawable-xhdpi/remote_56.png
deleted file mode 100644
index d57e067639a9b..0000000000000
Binary files a/packages/SystemUI/res/drawable-xhdpi/remote_56.png and /dev/null differ
diff --git a/packages/SystemUI/res/drawable-xhdpi/remote_57.png b/packages/SystemUI/res/drawable-xhdpi/remote_57.png
deleted file mode 100644
index a1bdae1108931..0000000000000
Binary files a/packages/SystemUI/res/drawable-xhdpi/remote_57.png and /dev/null differ
diff --git a/packages/SystemUI/res/drawable-xhdpi/remote_58.png b/packages/SystemUI/res/drawable-xhdpi/remote_58.png
deleted file mode 100644
index c8bc6a4548ad3..0000000000000
Binary files a/packages/SystemUI/res/drawable-xhdpi/remote_58.png and /dev/null differ
diff --git a/packages/SystemUI/res/drawable-xhdpi/remote_59.png b/packages/SystemUI/res/drawable-xhdpi/remote_59.png
deleted file mode 100644
index 526a24ea965ea..0000000000000
Binary files a/packages/SystemUI/res/drawable-xhdpi/remote_59.png and /dev/null differ
diff --git a/packages/SystemUI/res/drawable-xhdpi/remote_6.png b/packages/SystemUI/res/drawable-xhdpi/remote_6.png
deleted file mode 100644
index 2b6732fca80e6..0000000000000
Binary files a/packages/SystemUI/res/drawable-xhdpi/remote_6.png and /dev/null differ
diff --git a/packages/SystemUI/res/drawable-xhdpi/remote_60.png b/packages/SystemUI/res/drawable-xhdpi/remote_60.png
deleted file mode 100644
index 080619ecbc7f2..0000000000000
Binary files a/packages/SystemUI/res/drawable-xhdpi/remote_60.png and /dev/null differ
diff --git a/packages/SystemUI/res/drawable-xhdpi/remote_61.png b/packages/SystemUI/res/drawable-xhdpi/remote_61.png
deleted file mode 100644
index 5932a8ca29527..0000000000000
Binary files a/packages/SystemUI/res/drawable-xhdpi/remote_61.png and /dev/null differ
diff --git a/packages/SystemUI/res/drawable-xhdpi/remote_62.png b/packages/SystemUI/res/drawable-xhdpi/remote_62.png
deleted file mode 100644
index d1233dd34f3c4..0000000000000
Binary files a/packages/SystemUI/res/drawable-xhdpi/remote_62.png and /dev/null differ
diff --git a/packages/SystemUI/res/drawable-xhdpi/remote_63.png b/packages/SystemUI/res/drawable-xhdpi/remote_63.png
deleted file mode 100644
index 4f230c7cad230..0000000000000
Binary files a/packages/SystemUI/res/drawable-xhdpi/remote_63.png and /dev/null differ
diff --git a/packages/SystemUI/res/drawable-xhdpi/remote_64.png b/packages/SystemUI/res/drawable-xhdpi/remote_64.png
deleted file mode 100644
index 6b89fcbdcefd7..0000000000000
Binary files a/packages/SystemUI/res/drawable-xhdpi/remote_64.png and /dev/null differ
diff --git a/packages/SystemUI/res/drawable-xhdpi/remote_65.png b/packages/SystemUI/res/drawable-xhdpi/remote_65.png
deleted file mode 100644
index 87597b1fae43f..0000000000000
Binary files a/packages/SystemUI/res/drawable-xhdpi/remote_65.png and /dev/null differ
diff --git a/packages/SystemUI/res/drawable-xhdpi/remote_66.png b/packages/SystemUI/res/drawable-xhdpi/remote_66.png
deleted file mode 100644
index 0ee8c1e4ab817..0000000000000
Binary files a/packages/SystemUI/res/drawable-xhdpi/remote_66.png and /dev/null differ
diff --git a/packages/SystemUI/res/drawable-xhdpi/remote_67.png b/packages/SystemUI/res/drawable-xhdpi/remote_67.png
deleted file mode 100644
index 9aca8fddd52c7..0000000000000
Binary files a/packages/SystemUI/res/drawable-xhdpi/remote_67.png and /dev/null differ
diff --git a/packages/SystemUI/res/drawable-xhdpi/remote_68.png b/packages/SystemUI/res/drawable-xhdpi/remote_68.png
deleted file mode 100644
index 5f263aedff0c2..0000000000000
Binary files a/packages/SystemUI/res/drawable-xhdpi/remote_68.png and /dev/null differ
diff --git a/packages/SystemUI/res/drawable-xhdpi/remote_69.png b/packages/SystemUI/res/drawable-xhdpi/remote_69.png
deleted file mode 100644
index 1a22b61407c66..0000000000000
Binary files a/packages/SystemUI/res/drawable-xhdpi/remote_69.png and /dev/null differ
diff --git a/packages/SystemUI/res/drawable-xhdpi/remote_7.png b/packages/SystemUI/res/drawable-xhdpi/remote_7.png
deleted file mode 100644
index 9d9d699a6560b..0000000000000
Binary files a/packages/SystemUI/res/drawable-xhdpi/remote_7.png and /dev/null differ
diff --git a/packages/SystemUI/res/drawable-xhdpi/remote_70.png b/packages/SystemUI/res/drawable-xhdpi/remote_70.png
deleted file mode 100644
index 0372c50f3a8ab..0000000000000
Binary files a/packages/SystemUI/res/drawable-xhdpi/remote_70.png and /dev/null differ
diff --git a/packages/SystemUI/res/drawable-xhdpi/remote_71.png b/packages/SystemUI/res/drawable-xhdpi/remote_71.png
deleted file mode 100644
index 854e3e2b4bc72..0000000000000
Binary files a/packages/SystemUI/res/drawable-xhdpi/remote_71.png and /dev/null differ
diff --git a/packages/SystemUI/res/drawable-xhdpi/remote_72.png b/packages/SystemUI/res/drawable-xhdpi/remote_72.png
deleted file mode 100644
index 691962448e309..0000000000000
Binary files a/packages/SystemUI/res/drawable-xhdpi/remote_72.png and /dev/null differ
diff --git a/packages/SystemUI/res/drawable-xhdpi/remote_73.png b/packages/SystemUI/res/drawable-xhdpi/remote_73.png
deleted file mode 100644
index d8e9ae182e718..0000000000000
Binary files a/packages/SystemUI/res/drawable-xhdpi/remote_73.png and /dev/null differ
diff --git a/packages/SystemUI/res/drawable-xhdpi/remote_74.png b/packages/SystemUI/res/drawable-xhdpi/remote_74.png
deleted file mode 100644
index 24e5b6abcdf05..0000000000000
Binary files a/packages/SystemUI/res/drawable-xhdpi/remote_74.png and /dev/null differ
diff --git a/packages/SystemUI/res/drawable-xhdpi/remote_75.png b/packages/SystemUI/res/drawable-xhdpi/remote_75.png
deleted file mode 100644
index 369a3a9c0afdb..0000000000000
Binary files a/packages/SystemUI/res/drawable-xhdpi/remote_75.png and /dev/null differ
diff --git a/packages/SystemUI/res/drawable-xhdpi/remote_76.png b/packages/SystemUI/res/drawable-xhdpi/remote_76.png
deleted file mode 100644
index 96824c6dc5750..0000000000000
Binary files a/packages/SystemUI/res/drawable-xhdpi/remote_76.png and /dev/null differ
diff --git a/packages/SystemUI/res/drawable-xhdpi/remote_77.png b/packages/SystemUI/res/drawable-xhdpi/remote_77.png
deleted file mode 100644
index dd60ccad6ab38..0000000000000
Binary files a/packages/SystemUI/res/drawable-xhdpi/remote_77.png and /dev/null differ
diff --git a/packages/SystemUI/res/drawable-xhdpi/remote_78.png b/packages/SystemUI/res/drawable-xhdpi/remote_78.png
deleted file mode 100644
index aa3460bfc8906..0000000000000
Binary files a/packages/SystemUI/res/drawable-xhdpi/remote_78.png and /dev/null differ
diff --git a/packages/SystemUI/res/drawable-xhdpi/remote_79.png b/packages/SystemUI/res/drawable-xhdpi/remote_79.png
deleted file mode 100644
index 9a60e3c9b629a..0000000000000
Binary files a/packages/SystemUI/res/drawable-xhdpi/remote_79.png and /dev/null differ
diff --git a/packages/SystemUI/res/drawable-xhdpi/remote_8.png b/packages/SystemUI/res/drawable-xhdpi/remote_8.png
deleted file mode 100644
index b73c7efb6edd2..0000000000000
Binary files a/packages/SystemUI/res/drawable-xhdpi/remote_8.png and /dev/null differ
diff --git a/packages/SystemUI/res/drawable-xhdpi/remote_80.png b/packages/SystemUI/res/drawable-xhdpi/remote_80.png
deleted file mode 100644
index cbf883c7972ee..0000000000000
Binary files a/packages/SystemUI/res/drawable-xhdpi/remote_80.png and /dev/null differ
diff --git a/packages/SystemUI/res/drawable-xhdpi/remote_81.png b/packages/SystemUI/res/drawable-xhdpi/remote_81.png
deleted file mode 100644
index 11a6add24bde5..0000000000000
Binary files a/packages/SystemUI/res/drawable-xhdpi/remote_81.png and /dev/null differ
diff --git a/packages/SystemUI/res/drawable-xhdpi/remote_82.png b/packages/SystemUI/res/drawable-xhdpi/remote_82.png
deleted file mode 100644
index e05105d9b8eab..0000000000000
Binary files a/packages/SystemUI/res/drawable-xhdpi/remote_82.png and /dev/null differ
diff --git a/packages/SystemUI/res/drawable-xhdpi/remote_83.png b/packages/SystemUI/res/drawable-xhdpi/remote_83.png
deleted file mode 100644
index 57813aac5f0ae..0000000000000
Binary files a/packages/SystemUI/res/drawable-xhdpi/remote_83.png and /dev/null differ
diff --git a/packages/SystemUI/res/drawable-xhdpi/remote_84.png b/packages/SystemUI/res/drawable-xhdpi/remote_84.png
deleted file mode 100644
index 0f6f0fe6208b3..0000000000000
Binary files a/packages/SystemUI/res/drawable-xhdpi/remote_84.png and /dev/null differ
diff --git a/packages/SystemUI/res/drawable-xhdpi/remote_85.png b/packages/SystemUI/res/drawable-xhdpi/remote_85.png
deleted file mode 100644
index ada83ec852f48..0000000000000
Binary files a/packages/SystemUI/res/drawable-xhdpi/remote_85.png and /dev/null differ
diff --git a/packages/SystemUI/res/drawable-xhdpi/remote_86.png b/packages/SystemUI/res/drawable-xhdpi/remote_86.png
deleted file mode 100644
index 442dd5181e67a..0000000000000
Binary files a/packages/SystemUI/res/drawable-xhdpi/remote_86.png and /dev/null differ
diff --git a/packages/SystemUI/res/drawable-xhdpi/remote_87.png b/packages/SystemUI/res/drawable-xhdpi/remote_87.png
deleted file mode 100644
index bdb4962a72a23..0000000000000
Binary files a/packages/SystemUI/res/drawable-xhdpi/remote_87.png and /dev/null differ
diff --git a/packages/SystemUI/res/drawable-xhdpi/remote_88.png b/packages/SystemUI/res/drawable-xhdpi/remote_88.png
deleted file mode 100644
index b31800298bfdf..0000000000000
Binary files a/packages/SystemUI/res/drawable-xhdpi/remote_88.png and /dev/null differ
diff --git a/packages/SystemUI/res/drawable-xhdpi/remote_89.png b/packages/SystemUI/res/drawable-xhdpi/remote_89.png
deleted file mode 100644
index c4ed874495d60..0000000000000
Binary files a/packages/SystemUI/res/drawable-xhdpi/remote_89.png and /dev/null differ
diff --git a/packages/SystemUI/res/drawable-xhdpi/remote_9.png b/packages/SystemUI/res/drawable-xhdpi/remote_9.png
deleted file mode 100644
index ce5041f64f4eb..0000000000000
Binary files a/packages/SystemUI/res/drawable-xhdpi/remote_9.png and /dev/null differ
diff --git a/packages/SystemUI/res/drawable-xhdpi/remote_90.png b/packages/SystemUI/res/drawable-xhdpi/remote_90.png
deleted file mode 100644
index 6a662f9d65a7f..0000000000000
Binary files a/packages/SystemUI/res/drawable-xhdpi/remote_90.png and /dev/null differ
diff --git a/packages/SystemUI/res/drawable-xhdpi/remote_91.png b/packages/SystemUI/res/drawable-xhdpi/remote_91.png
deleted file mode 100644
index 21be887a1234f..0000000000000
Binary files a/packages/SystemUI/res/drawable-xhdpi/remote_91.png and /dev/null differ
diff --git a/packages/SystemUI/res/drawable-xhdpi/remote_92.png b/packages/SystemUI/res/drawable-xhdpi/remote_92.png
deleted file mode 100644
index 1bc536165bc84..0000000000000
Binary files a/packages/SystemUI/res/drawable-xhdpi/remote_92.png and /dev/null differ
diff --git a/packages/SystemUI/res/drawable-xhdpi/remote_93.png b/packages/SystemUI/res/drawable-xhdpi/remote_93.png
deleted file mode 100644
index 76495ac70941a..0000000000000
Binary files a/packages/SystemUI/res/drawable-xhdpi/remote_93.png and /dev/null differ
diff --git a/packages/SystemUI/res/drawable-xhdpi/remote_94.png b/packages/SystemUI/res/drawable-xhdpi/remote_94.png
deleted file mode 100644
index 081c84b9f011e..0000000000000
Binary files a/packages/SystemUI/res/drawable-xhdpi/remote_94.png and /dev/null differ
diff --git a/packages/SystemUI/res/drawable-xhdpi/remote_95.png b/packages/SystemUI/res/drawable-xhdpi/remote_95.png
deleted file mode 100644
index e9c27a8216b64..0000000000000
Binary files a/packages/SystemUI/res/drawable-xhdpi/remote_95.png and /dev/null differ
diff --git a/packages/SystemUI/res/drawable-xhdpi/remote_96.png b/packages/SystemUI/res/drawable-xhdpi/remote_96.png
deleted file mode 100644
index 13696031d6dc2..0000000000000
Binary files a/packages/SystemUI/res/drawable-xhdpi/remote_96.png and /dev/null differ
diff --git a/packages/SystemUI/res/drawable-xhdpi/remote_97.png b/packages/SystemUI/res/drawable-xhdpi/remote_97.png
deleted file mode 100644
index fbd14583d9896..0000000000000
Binary files a/packages/SystemUI/res/drawable-xhdpi/remote_97.png and /dev/null differ
diff --git a/packages/SystemUI/res/drawable-xhdpi/remote_98.png b/packages/SystemUI/res/drawable-xhdpi/remote_98.png
deleted file mode 100644
index ccdd7a7aecca8..0000000000000
Binary files a/packages/SystemUI/res/drawable-xhdpi/remote_98.png and /dev/null differ
diff --git a/packages/SystemUI/res/drawable-xhdpi/remote_99.png b/packages/SystemUI/res/drawable-xhdpi/remote_99.png
deleted file mode 100644
index f3cb4db410cb3..0000000000000
Binary files a/packages/SystemUI/res/drawable-xhdpi/remote_99.png and /dev/null differ
diff --git a/packages/SystemUI/res/drawable/tv_pip_onboarding_remote.xml b/packages/SystemUI/res/drawable/tv_pip_onboarding_remote.xml
deleted file mode 100644
index d46108ae6ffcb..0000000000000
--- a/packages/SystemUI/res/drawable/tv_pip_onboarding_remote.xml
+++ /dev/null
@@ -1,259 +0,0 @@
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
diff --git a/packages/SystemUI/res/drawable/tv_pip_overlay_background.xml b/packages/SystemUI/res/drawable/tv_pip_overlay_background.xml
deleted file mode 100644
index 2b58fc5a5fd3a..0000000000000
--- a/packages/SystemUI/res/drawable/tv_pip_overlay_background.xml
+++ /dev/null
@@ -1,20 +0,0 @@
-
-
-
-
-
diff --git a/packages/SystemUI/res/drawable/tv_pip_overlay_text_background.xml b/packages/SystemUI/res/drawable/tv_pip_overlay_text_background.xml
deleted file mode 100644
index e247dec3ae27e..0000000000000
--- a/packages/SystemUI/res/drawable/tv_pip_overlay_text_background.xml
+++ /dev/null
@@ -1,23 +0,0 @@
-
-
-
-
-
diff --git a/packages/SystemUI/res/drawable/tv_pip_recents_overlay_scrim.xml b/packages/SystemUI/res/drawable/tv_pip_recents_overlay_scrim.xml
deleted file mode 100644
index 57bee75165ee7..0000000000000
--- a/packages/SystemUI/res/drawable/tv_pip_recents_overlay_scrim.xml
+++ /dev/null
@@ -1,23 +0,0 @@
-
-
-
-
-
diff --git a/packages/SystemUI/res/layout/tv_pip_onboarding.xml b/packages/SystemUI/res/layout/tv_pip_onboarding.xml
deleted file mode 100644
index fe80b9464a019..0000000000000
--- a/packages/SystemUI/res/layout/tv_pip_onboarding.xml
+++ /dev/null
@@ -1,102 +0,0 @@
-
-
-
-
-
-
-
-
-
-
-
-
diff --git a/packages/SystemUI/res/layout/tv_pip_overlay.xml b/packages/SystemUI/res/layout/tv_pip_overlay.xml
deleted file mode 100644
index 608680cdf25f0..0000000000000
--- a/packages/SystemUI/res/layout/tv_pip_overlay.xml
+++ /dev/null
@@ -1,42 +0,0 @@
-
-
-
-
-
-
-
diff --git a/packages/SystemUI/res/values/colors_tv.xml b/packages/SystemUI/res/values/colors_tv.xml
index 3817da0174263..6e56d4a38d0c5 100644
--- a/packages/SystemUI/res/values/colors_tv.xml
+++ b/packages/SystemUI/res/values/colors_tv.xml
@@ -21,4 +21,4 @@
#CCEEEEEE
#7FEEEEEE
#7F000000
-
\ No newline at end of file
+
diff --git a/packages/SystemUI/res/values/dimens_tv.xml b/packages/SystemUI/res/values/dimens_tv.xml
deleted file mode 100644
index 30355d47e9577..0000000000000
--- a/packages/SystemUI/res/values/dimens_tv.xml
+++ /dev/null
@@ -1,22 +0,0 @@
-
-
-
-
- 3dp
-
diff --git a/packages/SystemUI/res/values/integers_tv.xml b/packages/SystemUI/res/values/integers_tv.xml
deleted file mode 100644
index 09547dad07056..0000000000000
--- a/packages/SystemUI/res/values/integers_tv.xml
+++ /dev/null
@@ -1,21 +0,0 @@
-
-
-
-
- 1000
-
- 1000
-
diff --git a/packages/SystemUI/res/values/strings_tv.xml b/packages/SystemUI/res/values/strings_tv.xml
index fb9e1f25f4dd9..41626fcb0a49b 100644
--- a/packages/SystemUI/res/values/strings_tv.xml
+++ b/packages/SystemUI/res/values/strings_tv.xml
@@ -27,14 +27,4 @@
Play
Pause
-
- Hold HOME to control PIP
-
-
-
- Picture-in-picture
-
- This keeps your video in view until you play another one. Press and hold HOME to control it.
-
- Got it
diff --git a/packages/SystemUI/src/com/android/systemui/Prefs.java b/packages/SystemUI/src/com/android/systemui/Prefs.java
index e1aaaa36d77a2..1e9cbdc45425c 100644
--- a/packages/SystemUI/src/com/android/systemui/Prefs.java
+++ b/packages/SystemUI/src/com/android/systemui/Prefs.java
@@ -41,7 +41,6 @@ public final class Prefs {
Key.DND_FAVORITE_BUCKET_INDEX,
Key.DND_NONE_SELECTED,
Key.DND_FAVORITE_ZEN,
- Key.TV_PICTURE_IN_PICTURE_ONBOARDING_SHOWN,
Key.QS_HOTSPOT_ADDED,
Key.QS_DATA_SAVER_ADDED,
Key.QS_DATA_SAVER_DIALOG_SHOWN,
@@ -62,7 +61,6 @@ public final class Prefs {
String DND_FAVORITE_BUCKET_INDEX = "DndCountdownMinuteIndex";
String DND_NONE_SELECTED = "DndNoneSelected";
String DND_FAVORITE_ZEN = "DndFavoriteZen";
- String TV_PICTURE_IN_PICTURE_ONBOARDING_SHOWN = "TvPictureInPictureOnboardingShown";
String QS_HOTSPOT_ADDED = "QsHotspotAdded";
String QS_DATA_SAVER_ADDED = "QsDataSaverAdded";
String QS_DATA_SAVER_DIALOG_SHOWN = "QsDataSaverDialogShown";
diff --git a/packages/SystemUI/src/com/android/systemui/pip/tv/PipMenuActivity.java b/packages/SystemUI/src/com/android/systemui/pip/tv/PipMenuActivity.java
index 9945079445a87..ce1bea19ef609 100644
--- a/packages/SystemUI/src/com/android/systemui/pip/tv/PipMenuActivity.java
+++ b/packages/SystemUI/src/com/android/systemui/pip/tv/PipMenuActivity.java
@@ -56,7 +56,7 @@ public class PipMenuActivity extends Activity implements PipManager.Listener {
private void restorePipAndFinish() {
if (mRestorePipSizeWhenClose) {
// When PIP menu activity is closed, restore to the default position.
- mPipManager.resizePinnedStack(PipManager.STATE_PIP_OVERLAY);
+ mPipManager.resizePinnedStack(PipManager.STATE_PIP);
}
finish();
}
diff --git a/packages/SystemUI/src/com/android/systemui/pip/tv/PipOnboardingActivity.java b/packages/SystemUI/src/com/android/systemui/pip/tv/PipOnboardingActivity.java
deleted file mode 100644
index 423530a70c044..0000000000000
--- a/packages/SystemUI/src/com/android/systemui/pip/tv/PipOnboardingActivity.java
+++ /dev/null
@@ -1,131 +0,0 @@
-/*
- * Copyright (C) 2016 The Android Open Source Project
- *
- * Licensed under the Apache License, Version 2.0 (the "License");
- * you may not use this file except in compliance with the License.
- * You may obtain a copy of the License at
- *
- * http://www.apache.org/licenses/LICENSE-2.0
- *
- * Unless required by applicable law or agreed to in writing, software
- * distributed under the License is distributed on an "AS IS" BASIS,
- * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
- * See the License for the specific language governing permissions and
- * limitations under the License.
- */
-
-package com.android.systemui.pip.tv;
-
-import android.animation.Animator;
-import android.animation.AnimatorInflater;
-import android.animation.AnimatorListenerAdapter;
-import android.animation.AnimatorSet;
-import android.app.Activity;
-import android.graphics.drawable.AnimationDrawable;
-import android.os.Bundle;
-import android.view.View;
-import android.view.KeyEvent;
-import android.widget.ImageView;
-
-import com.android.systemui.R;
-
-/**
- * Activity to show an overlay on top of PIP activity to show how to pop up PIP menu.
- */
-public class PipOnboardingActivity extends Activity implements PipManager.Listener {
- private final PipManager mPipManager = PipManager.getInstance();
- private AnimatorSet mEnterAnimator;
-
- @Override
- protected void onCreate(Bundle bundle) {
- super.onCreate(bundle);
- setContentView(R.layout.tv_pip_onboarding);
- findViewById(R.id.button).setOnClickListener(new View.OnClickListener() {
- @Override
- public void onClick(View v) {
- finish();
- }
- });
-
- mPipManager.addListener(this);
- }
-
- @Override
- public void onResume() {
- super.onResume();
- mEnterAnimator = new AnimatorSet();
- mEnterAnimator.playTogether(
- loadAnimator(R.id.background, R.anim.tv_pip_onboarding_background_enter_animation),
- loadAnimator(R.id.remote, R.anim.tv_pip_onboarding_image_enter_animation),
- loadAnimator(R.id.remote_button, R.anim.tv_pip_onboarding_image_enter_animation),
- loadAnimator(R.id.title, R.anim.tv_pip_onboarding_title_enter_animation),
- loadAnimator(R.id.description,
- R.anim.tv_pip_onboarding_description_enter_animation),
- loadAnimator(R.id.button, R.anim.tv_pip_onboarding_button_enter_animation));
- mEnterAnimator.addListener(new AnimatorListenerAdapter() {
- @Override
- public void onAnimationStart(Animator animation) {
- ImageView button = findViewById(R.id.remote_button);
- ((AnimationDrawable) button.getDrawable()).start();
- }
- });
- int delay = getResources().getInteger(R.integer.tv_pip_onboarding_anim_start_delay);
- mEnterAnimator.setStartDelay(delay);
- mEnterAnimator.start();
- }
-
- private Animator loadAnimator(int viewResId, int animResId) {
- Animator animator = AnimatorInflater.loadAnimator(this, animResId);
- animator.setTarget(findViewById(viewResId));
- return animator;
- }
-
- @Override
- public boolean onKeyUp(int keyCode, KeyEvent event) {
- if (mEnterAnimator.isStarted()) {
- return true;
- }
- return super.onKeyUp(keyCode, event);
- }
-
- @Override
- public boolean onKeyDown(int keyCode, KeyEvent event) {
- if (mEnterAnimator.isStarted()) {
- return true;
- }
- return super.onKeyDown(keyCode, event);
- }
-
- @Override
- public void onPause() {
- super.onPause();
- finish();
- }
-
- @Override
- protected void onDestroy() {
- super.onDestroy();
- mPipManager.removeListener(this);
- }
-
- @Override
- public void onPipEntered() { }
-
- @Override
- public void onPipActivityClosed() {
- finish();
- }
-
- @Override
- public void onShowPipMenu() {
- finish();
- }
-
- @Override
- public void onMoveToFullscreen() {
- finish();
- }
-
- @Override
- public void onPipResizeAboutToStart() { }
-}
diff --git a/packages/SystemUI/src/com/android/systemui/pip/tv/PipOverlayActivity.java b/packages/SystemUI/src/com/android/systemui/pip/tv/PipOverlayActivity.java
deleted file mode 100644
index f52121ff119f7..0000000000000
--- a/packages/SystemUI/src/com/android/systemui/pip/tv/PipOverlayActivity.java
+++ /dev/null
@@ -1,138 +0,0 @@
-/*
- * Copyright (C) 2016 The Android Open Source Project
- *
- * Licensed under the Apache License, Version 2.0 (the "License");
- * you may not use this file except in compliance with the License.
- * You may obtain a copy of the License at
- *
- * http://www.apache.org/licenses/LICENSE-2.0
- *
- * Unless required by applicable law or agreed to in writing, software
- * distributed under the License is distributed on an "AS IS" BASIS,
- * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
- * See the License for the specific language governing permissions and
- * limitations under the License.
- */
-
-package com.android.systemui.pip.tv;
-
-import android.animation.Animator;
-import android.animation.AnimatorInflater;
-import android.app.Activity;
-import android.app.ActivityOptions;
-import android.content.Context;
-import android.content.Intent;
-import android.os.Bundle;
-import android.os.Handler;
-import android.view.View;
-import android.widget.ImageView;
-
-import com.android.systemui.R;
-
-import static android.app.ActivityManager.StackId.PINNED_STACK_ID;
-
-/**
- * Activity to show an overlay on top of PIP activity to show how to pop up PIP menu.
- */
-public class PipOverlayActivity extends Activity implements PipManager.Listener {
- private static final long SHOW_GUIDE_OVERLAY_VIEW_DURATION_MS = 4000;
-
- /**
- * A flag to ensure the single instance of PipOverlayActivity to prevent it from restarting.
- * Note that {@link PipManager} moves the PIPed activity to fullscreen if the activity is
- * restarted. It's because the activity may be started by the Launcher or an intent again,
- * but we don't want do so for the PipOverlayActivity.
- */
- private static boolean sActivityCreated;
-
- private final PipManager mPipManager = PipManager.getInstance();
- private final Handler mHandler = new Handler();
- private View mGuideOverlayView;
- private View mGuideButtonsView;
- private ImageView mGuideButtonPlayPauseImageView;
- private final Runnable mHideGuideOverlayRunnable = new Runnable() {
- public void run() {
- mFadeOutAnimation.start();
- }
- };
- private Animator mFadeInAnimation;
- private Animator mFadeOutAnimation;
-
- /**
- * Shows PIP overlay UI only if it's not there.
- */
- static void showPipOverlay(Context context) {
- if (!sActivityCreated) {
- Intent intent = new Intent(context, PipOverlayActivity.class);
- intent.setFlags(Intent.FLAG_ACTIVITY_NEW_TASK);
- final ActivityOptions options = ActivityOptions.makeBasic();
- options.setLaunchStackId(PINNED_STACK_ID);
- context.startActivity(intent, options.toBundle());
- }
- }
-
- @Override
- protected void onCreate(Bundle bundle) {
- super.onCreate(bundle);
- sActivityCreated = true;
- setContentView(R.layout.tv_pip_overlay);
- mGuideOverlayView = findViewById(R.id.guide_overlay);
- mPipManager.addListener(this);
- mFadeInAnimation = AnimatorInflater.loadAnimator(
- this, R.anim.tv_pip_overlay_fade_in_animation);
- mFadeInAnimation.setTarget(mGuideOverlayView);
- mFadeOutAnimation = AnimatorInflater.loadAnimator(
- this, R.anim.tv_pip_overlay_fade_out_animation);
- mFadeOutAnimation.setTarget(mGuideOverlayView);
- }
-
- @Override
- protected void onResume() {
- super.onResume();
- mFadeInAnimation.start();
- mHandler.removeCallbacks(mHideGuideOverlayRunnable);
- mHandler.postDelayed(mHideGuideOverlayRunnable, SHOW_GUIDE_OVERLAY_VIEW_DURATION_MS);
- }
-
- @Override
- protected void onStop() {
- super.onStop();
- mHandler.removeCallbacks(mHideGuideOverlayRunnable);
- finish();
- }
-
- @Override
- protected void onDestroy() {
- super.onDestroy();
- sActivityCreated = false;
- mHandler.removeCallbacksAndMessages(null);
- mPipManager.removeListener(this);
- mPipManager.resumePipResizing(
- PipManager.SUSPEND_PIP_RESIZE_REASON_WAITING_FOR_OVERLAY_ACTIVITY_FINISH);
- }
-
- @Override
- public void onPipEntered() { }
-
- @Override
- public void onPipActivityClosed() {
- finish();
- }
-
- @Override
- public void onShowPipMenu() {
- finish();
- }
-
- @Override
- public void onMoveToFullscreen() {
- finish();
- }
-
- @Override
- public void onPipResizeAboutToStart() {
- finish();
- mPipManager.suspendPipResizing(
- PipManager.SUSPEND_PIP_RESIZE_REASON_WAITING_FOR_OVERLAY_ACTIVITY_FINISH);
- }
-}
diff --git a/packages/SystemUI/src/com/android/systemui/recents/misc/SystemServicesProxy.java b/packages/SystemUI/src/com/android/systemui/recents/misc/SystemServicesProxy.java
index 397b78dbd281b..ccebd7ceec329 100644
--- a/packages/SystemUI/src/com/android/systemui/recents/misc/SystemServicesProxy.java
+++ b/packages/SystemUI/src/com/android/systemui/recents/misc/SystemServicesProxy.java
@@ -82,7 +82,6 @@ import com.android.internal.os.BackgroundThread;
import com.android.keyguard.KeyguardUpdateMonitor;
import com.android.systemui.R;
import com.android.systemui.pip.tv.PipMenuActivity;
-import com.android.systemui.pip.tv.PipOnboardingActivity;
import com.android.systemui.recents.Recents;
import com.android.systemui.recents.RecentsDebugFlags;
import com.android.systemui.recents.RecentsImpl;
@@ -113,7 +112,6 @@ public class SystemServicesProxy {
final static List sRecentsBlacklist;
static {
sRecentsBlacklist = new ArrayList<>();
- sRecentsBlacklist.add(PipOnboardingActivity.class.getName());
sRecentsBlacklist.add(PipMenuActivity.class.getName());
}
diff --git a/packages/SystemUI/src/com/android/systemui/pip/tv/PipManager.java b/packages/SystemUI/src/com/android/systemui/pip/tv/PipManager.java
index ad290c388cb01..f2f0d7a5a86c3 100644
--- a/packages/SystemUI/src/com/android/systemui/pip/tv/PipManager.java
+++ b/packages/SystemUI/src/com/android/systemui/pip/tv/PipManager.java
@@ -56,16 +56,12 @@ import java.util.List;
import static android.app.ActivityManager.StackId.PINNED_STACK_ID;
import static android.view.Display.DEFAULT_DISPLAY;
-import static com.android.systemui.Prefs.Key.TV_PICTURE_IN_PICTURE_ONBOARDING_SHOWN;
-
/**
* Manages the picture-in-picture (PIP) UI and states.
*/
public class PipManager implements BasePipManager {
private static final String TAG = "PipManager";
private static final boolean DEBUG = Log.isLoggable(TAG, Log.DEBUG);
- private static final boolean DEBUG_FORCE_ONBOARDING =
- SystemProperties.getBoolean("debug.tv.pip_force_onboarding", false);
private static final String SETTINGS_PACKAGE_AND_CLASS_DELIMITER = "/";
private static PipManager sPipManager;
@@ -76,10 +72,9 @@ public class PipManager implements BasePipManager {
*/
public static final int STATE_NO_PIP = 0;
/**
- * State when PIP is shown with an overlay message on top of it.
- * This is used as default PIP state.
+ * State when PIP is shown. This is used as default PIP state.
*/
- public static final int STATE_PIP_OVERLAY = 1;
+ public static final int STATE_PIP = 1;
/**
* State when PIP menu dialog is shown.
*/
@@ -126,7 +121,6 @@ public class PipManager implements BasePipManager {
private int mPipTaskId = TASK_ID_NO_PIP;
private ComponentName mPipComponentName;
private MediaController mPipMediaController;
- private boolean mOnboardingShown;
private String[] mLastPackagesResourceGranted;
private final PinnedStackListener mPinnedStackListener = new PinnedStackListener();
@@ -212,8 +206,6 @@ public class PipManager implements BasePipManager {
IntentFilter intentFilter = new IntentFilter();
intentFilter.addAction(Intent.ACTION_MEDIA_RESOURCE_GRANTED);
mContext.registerReceiver(mBroadcastReceiver, intentFilter);
- mOnboardingShown = Prefs.getBoolean(
- mContext, TV_PICTURE_IN_PICTURE_ONBOARDING_SHOWN, false);
if (sSettingsPackageAndClassNamePairList == null) {
String[] settings = mContext.getResources().getStringArray(
@@ -267,7 +259,7 @@ public class PipManager implements BasePipManager {
// 1. Configuration changed due to the language change (RTL <-> RTL)
// 2. SystemUI restarts after the crash
mPipBounds = isSettingsShown() ? mSettingsPipBounds : mDefaultPipBounds;
- resizePinnedStack(getPinnedStackInfo() == null ? STATE_NO_PIP : STATE_PIP_OVERLAY);
+ resizePinnedStack(getPinnedStackInfo() == null ? STATE_NO_PIP : STATE_PIP);
}
/**
@@ -281,7 +273,7 @@ public class PipManager implements BasePipManager {
* Shows the picture-in-picture menu if an activity is in picture-in-picture mode.
*/
public void showPictureInPictureMenu() {
- if (mState == STATE_PIP_OVERLAY) {
+ if (mState == STATE_PIP) {
resizePinnedStack(STATE_PIP_MENU);
}
}
@@ -324,16 +316,6 @@ public class PipManager implements BasePipManager {
updatePipVisibility(false);
}
- /**
- * Shows PIP overlay UI by launching {@link PipOverlayActivity}. It also locates the pinned
- * stack to the default PIP bound {@link com.android.internal.R.string
- * .config_defaultPictureInPictureBounds}.
- */
- private void showPipOverlay() {
- if (DEBUG) Log.d(TAG, "showPipOverlay()");
- PipOverlayActivity.showPipOverlay(mContext);
- }
-
/**
* Suspends resizing operation on the Pip until {@link #resumePipResizing} is called
* @param reason The reason for suspending resizing operations on the Pip.
@@ -388,7 +370,7 @@ public class PipManager implements BasePipManager {
case STATE_PIP_MENU:
mCurrentPipBounds = mMenuModePipBounds;
break;
- case STATE_PIP_OVERLAY:
+ case STATE_PIP:
mCurrentPipBounds = mPipBounds;
break;
default:
@@ -454,17 +436,6 @@ public class PipManager implements BasePipManager {
mMediaListeners.remove(listener);
}
- private void launchPipOnboardingActivityIfNeeded() {
- if (DEBUG_FORCE_ONBOARDING || !mOnboardingShown) {
- mOnboardingShown = true;
- Prefs.putBoolean(mContext, TV_PICTURE_IN_PICTURE_ONBOARDING_SHOWN, true);
-
- Intent intent = new Intent(mContext, PipOnboardingActivity.class);
- intent.setFlags(Intent.FLAG_ACTIVITY_NEW_TASK);
- mContext.startActivity(intent);
- }
- }
-
/**
* Returns {@code true} if PIP is shown.
*/
@@ -617,11 +588,11 @@ public class PipManager implements BasePipManager {
return;
}
}
- if (mState == STATE_PIP_OVERLAY) {
+ if (mState == STATE_PIP) {
Rect bounds = isSettingsShown() ? mSettingsPipBounds : mDefaultPipBounds;
if (mPipBounds != bounds) {
mPipBounds = bounds;
- resizePinnedStack(STATE_PIP_OVERLAY);
+ resizePinnedStack(STATE_PIP);
}
}
}
@@ -641,10 +612,9 @@ public class PipManager implements BasePipManager {
mPipTaskId = stackInfo.taskIds[stackInfo.taskIds.length - 1];
mPipComponentName = ComponentName.unflattenFromString(
stackInfo.taskNames[stackInfo.taskNames.length - 1]);
- // Set state to overlay so we show it when the pinned stack animation ends.
- mState = STATE_PIP_OVERLAY;
+ // Set state to STATE_PIP so we show it when the pinned stack animation ends.
+ mState = STATE_PIP;
mCurrentPipBounds = mPipBounds;
- launchPipOnboardingActivityIfNeeded();
mMediaSessionManager.addOnActiveSessionsChangedListener(
mActiveMediaSessionListener, null);
updateMediaController(mMediaSessionManager.getActiveSessions(null));
@@ -671,9 +641,6 @@ public class PipManager implements BasePipManager {
return;
}
switch (mState) {
- case STATE_PIP_OVERLAY:
- showPipOverlay();
- break;
case STATE_PIP_MENU:
showPipMenu();
break;